
'       This is an example of data transfer

'      This program will start from the data for South Africa
'       provided by the World Bank

'      The remaining problems will be noted "*****pb"
'      and specific remarks will be noted "*****rem"

'      We decide on the directory
'      This is not generally necessary
'       except if one works on several projects
'      or maintains several directories for the same project
'       It guarantees trial versions do not destroy official ones

cd "c:\users\jean louis brillet\documents\eviews\book_africa2\afsud"

'     The original data is contained in a page called "wb" with the original names
'     The page "model" contains links to the "wb" series
'      with the addition of a "v_" prefix

'-------------------------------------------------------------------------
'     This technique can be used with any source 

'      In the best case, if the set available is the same (or larger) than the World Bank set
'      one has just to replace the World Bank names in the following statements
'-------------------------------------------------------------------------

'       we close the original file "afsegal_wb"  
'      in case it is already open 
'      having two versions of the same file open in memory is quite dangenrous...

close data_afs 

'     We open it again

open data_afs

'       We copy the definition of the group to a page called "model"
 
'       We delete the page if it exists

pagedelete model

'       We create the page annual from 1960 to 2020

pagecreate(page=model) a 1960 2020
delete *

'      We copy the definition of the group g_wb (not the series) from the page wb to model
'      This is done by "g=l"

copy(g=l) wb\g_wb   

'       We create linked variables adding the prefix "v_" to the original series names
'       to separate them from the variables we are going to compute 

smpl 1960 2020
for !i=1 to g_wb.@count

'     We get the name

%1=g_wb.@seriesname(!i)

'     We  create the linked variable

link v_{%1}

'    We establish the link

v_{%1}.linkto wb\{%1}
next   

'      We copy the definition of the group g_ilo (not the series) from the page wb to model
'      This is done by "g=l"

copy(g=l) ilo\g_ilo   

'       We create linked variables adding the prefix "v_" to the original series names
'       to separate them from the variables we are going to compute

smpl 1960 2020
for !i=1 to g_ilo.@count

'     We get the name

%1=g_ilo.@seriesname(!i)

'     We  create the linked variable

link l_{%1}

'    We establish the link

l_{%1}.linkto ilo\{%1}
next   

'     We generate a time trend

smpl 1960 1960
genr t=1960
smpl 1961 2020
genr t=t(-1)+1
pageselect model

'     We have to make an assumption on the sharing of indirect taxes 
'     into VAT and other indirect taxes
'     as OECD provides only a global variable

'     p_oit = assumption on the share of oit in indirect taxes

'     indirect taxes are not separated into VAT and other taxes

'    Our series will have the prefix "a_" for South Africa
'    this is to separate them from series for other countries if they share the same page
'    The prefix can be easily discarded later
'
scalar a_p_oit=0.2

scalar txq=0.05
scalar txn=0.01
scalar txp=0.05

'     we create a time trend
'     with the value of the year for the first quarter
'     to which we add 1 for each following quarter of the year 

'   This will be quite useful to :

'      create yearly time trends
'      replace actual dummy variables by expressions using logical conditions
'      much easier to manage

smpl 1960 1960
genr a_t=1960
smpl 1961 2020
genr a_t=a_t(-1)+1

'     Now we start with the supply - demand equilibrium

smpl 1960 2020
genr a_usd=v_PA_NUS_FCRF
genr a_gdpv=v_ny_gdp_mktp_cn
genr a_gdp=v_ny_gdp_mktp_kn

'   The model separates market GDP


genr a_cohv=v_ne_con_petc_cn
genr a_coh=v_ne_con_petc_kn
genr a_pcoh=a_cohv/a_coh

genr a_cgw=0
genr a_gdpmv=a_gdpv-a_cgw
genr a_gdpm=a_GDP-a_CGw/a_pcoh
genr a_pgdpm=a_gdpmv/a_gdpm

'      Trade af current and constant prices, associated deflators

genr a_mv=v_ne_imp_gnfs_cn
genr a_m=v_ne_imp_gnfs_kn
genr a_pm=a_mv/a_m
genr a_xv=v_ne_exp_gnfs_cn
genr a_x=v_ne_exp_gnfs_kn
genr a_px=a_xv/a_x

'      Final demand, VAT and value added (excluding VAT)
'      This separation is important as VAT will apply to final demand

genr a_fd=a_GDPm+a_M-a_X
genr a_fdv=a_GDPmV+a_MV-a_XV

'       We generate series for Final demand produced locally

genr a_FDLV=a_GDPMV-a_XV
genr a_FDL=a_GDPM-a_X
genr a_PFDL=a_FDLV/a_FDL
genr a_pfd=a_fdv/a_fd
genr a_oit=(1-a_p_oit)*v_ny_tax_nind_cn 
genr a_vat =a_p_oit*v_ny_tax_nind_cn 
genr a_r_vat =a_vat/(a_fd*a_pfd-a_vat)

'       value added (excluding VAT)

genr a_qv=a_gdpmv-a_vat
genr a_r_oit=a_oit/(a_qv-a_oit)
scalar a_r_vat0=@elem(a_r_vat,"2005")
genr a_q = a_gdpm-a_r_vat0*a_fd/(1+a_r_vat0)
genr a_pq=a_qv/a_q

'      Investment

'    *****pb : government investment

genr a_ihv=0      '    *****pb : no measure of housing investment
genr a_ih=0        '    *****pb : no measure of housing investment
genr a_ipv=v_ne_gdi_fprv_cn
genr a_igv=v_ne_gdi_ftot_cn- v_ne_gdi_fprv_cn 
genr a_ip=v_ne_gdi_ftot_kn*a_ipv/(a_ipv+a_igv+a_ihv)
genr a_ig=v_ne_gdi_ftot_kn*a_igv/(a_ipv+a_igv+a_ihv)
genr a_pip=a_ipv/a_ip
genr a_pig=a_igv/a_ig
genr a_dep=v_ny_adj_dkap_cd   ' *****rem additional measure of depreciation in USD

'    Capital and capacities

genr a_cap=a_q     ' *****rem : will be computed after estimation of production function
smpl 1964 2013
genr a_k=2*a_q
genr a_rdep = 0.05
smpl 1965 2013
genr a_k=a_k(-1)*(1-a_rdep)+a_ip
smpl @all

'     The rate of use

genr a_ur=a_q/a_k'-1) 
genr a_pk=a_cap/a_k(-1)
genr a_urd=1

'      We assume that for each unit of value added we need one unit of intermediary consumption 
'      this is generally not too far from the truth

genr a_tc=1
genr a_ci=a_tc*a_q

'      Total demand

genr a_td=a_fd+a_ci

'    Elements of demand 

'       Changes in inventories

genr a_icv=v_ne_gdi_stkb_cn
genr a_ic=v_ne_gdi_stkb_kn
genr a_pic=a_icv/a_ic

'        Government consumption (includes wages of civl servants)

genr a_cogv=v_ne_con_govt_cn
genr a_cog=v_ne_con_govt_kn
genr a_pcog=a_cogv/a_cog
genr a_r_pcog=a_pcog/a_pfd

'         Final demand of Government

genr a_fdgv=a_cogv+a_igv
genr a_fdg=a_cog+a_ig
genr a_gd=a_ig+a_cog
genr a_fdxr=0    '    *****rem : look further into the composition of demand

'    employment, unemployment, population

genr a_popt=v_sp_pop_totl
genr a_pop1564=a_popt*v_sp_pop_1564_to_zs/100
genr a_lt=v_sl_emp_totl_sp_zs*a_pop1564/100
genr a_lg=0         '  *****pb : no measure of civil servants. Will have to be changed
genr a_lf=a_lt-a_lg
genr a_pl=a_q / a_lf
genr a_un=v_sl_uem_totl_zs*v_sl_tlf_totl_in/100    '   *****rem : un known only in 2006
genr a_unr=a_UN/(a_lt+a_un)*100  
genr a_popac=a_lt+a_un
genr a_lp=a_q/a_lf

'    wages and further deflators

genr a_ls=v_sl_emp_self_zs*a_lt/100  

'    We interpolate the number of self employed

'     First we compute the share as scalars for the years for which we have the information

scalar a_rls1=@elem(a_ls,"2003")/@elem(a_lt,"2003")
scalar a_rls2=@elem(a_ls,"2004")/@elem(a_lt,"2004")
scalar a_rls3=@elem(a_ls,"2007")/@elem(a_lt,"2007")
scalar a_rls4=@elem(a_ls,"2011")/@elem(a_lt,"2011")

'    We use the first scalar to retropolate 

smpl 1991 2002
genr a_ls=a_lt*a_rls1

'    The second and the third to interpolate 

smpl 2005 2006
genr a_ls=a_lt*(a_rls2+(a_t-2004)/3*(a_rls3-a_rls2))

'    The last to extrapolate

smpl 2012 2012
genr a_ls=a_lt*a_rls4

'     We compute the number of wage earners

smpl @all
genr a_lw=a_lf-a_ls
genr a_r_lw=a_lw/a_lf 

'     The production price is the deflator of production 
'     using a demand deflator excluding vat


genr a_pfdxt=a_pfd*(1+a_r_vat0)/(1+a_r_vat)
genr a_tc=1     ' ******rem : assumption
genr a_pp=(a_pq+a_tc*a_pfdxt)/(1+a_tc) 

genr a_r_scf =0      ' ****** unknown social contributions. Will have to be changed.
genr a_scf=0

'      The wage rate

'     It is not known in 2003 and 2004
'     we interpolate it

genr a_wr_man=l_w_ima
smpl 2003 2004
genr log(a_wr_man)=@elem(log(a_wr_man),"2002")+(t-2002)/3*(@elem(log(a_wr_man),"2005")-@elem(log(a_wr_man),"2002")) 

'      After 2008 we make it grow like the consumption price index

smpl 2009 2012  
genr @pch(a_wr_man)=@pch(a_pcoh) 
smpl @all 

'   The yearly value

genr a_wr=a_wr_man*12

'    Total wages

genr a_wage=a_wr*(a_lt-a_ls)
genr a_r_scw=0.10        '  *****pb : no measure of contributions by employees '
genr a_scw=a_r_scw*a_wage 
genr a_wagef=a_wr*(a_lf-a_ls)
genr a_wageg=a_wr*a_lg
genr a_uwc=a_wr*(1+a_r_scf)/a_lp

'      The demand price excluding VAT

genr a_ern=v_pa_nus_fcrf 

'       The exchange rate as a deflator

genr a_er=a_ern/@elem(a_ern,"2005")
genr a_erx=a_er

'       ratios between demand prices

genr a_r_pip=a_pip/a_pfd
genr a_r_pcoh=a_pcoh/a_pfd
genr a_r_pig=a_pig/a_pfd

'    interest rates
 
genr a_irs=v_fr_inr_dpst    
genr a_irl=v_fr_inr_dpst     
genr a_ir=0.5*(a_irs+a_irl)
genr a_irm=a_ir 
genr a_irsx=a_irs
genr a_irx=a_ir
genr a_irr=a_ir-100*@pch(a_pcoh)
genr a_irl_ec=0
genr a_ir_ec=0
genr a_irsr=a_irs-100*@pchy(a_pcoh)
genr a_irst=0 

'    The relative cost

genr a_relc=a_wr*(1+a_r_scf)/a_pip/(a_ir/100-@pchy(a_pcoh)+a_rdep)
smpl 1978 2013
genr a_irm=0.2*a_ir+0.8*a_irm(-1) 
genr a_irmx=a_irm

'---------------------------------------
'     Households
'---------------------------------------

smpl @all
genr a_rem=v_BX_TRF_PWKR_DT_GD_ZS*a_gdpv/100

'      Remittances are extrapolated in 2011 and 2012

smpl 2011 2012
genr a_rem=a_rem(-1)*a_gdpv/a_gdpv(-1)
smpl @all

'      remittances

genr a_remx=a_rem/a_er
genr a_socb=v_sh_xpd_publ_zs*a_gdpv/100    '  *****rem : govt health expenditures
genr a_socbr =a_socb/a_pcoh/a_popt

'      Social benefits are retropolated iuntil 1994

smpl @first 1994
genr a_socb =@elem(a_socb,"1995")*a_gdpv/@elem(a_gdpv,"1995")
genr a_socbr =a_socb/a_pcoh/a_popt
smpl @all

'      Direct taxes are shared between firms and households

genr a_ifp=0.5*v_gc_tax_ypkg_cn   ' ****rem : division 0.5 
genr a_ict=0.5*v_gc_tax_ypkg_cn
genr a_subs=v_gc_xpn_trft_cn  '   *****rem :  
genr a_tar=v_gc_tax_impt_cn   '   ***** rem  
genr a_tar=v_gc_tax_intt_cn  '   *****rem : which is the right series?

'      Rates

genr a_r_subs = a_subs/a_qv
genr a_r_tar=a_tar/a_mv  

'      Retro and extra polations

smpl @first 1999
genr a_r_subs=@elem(a_r_subs,"2000")
smpl 2012 2012
genr a_r_subs=@elem(a_r_subs,"2011")
smpl 2012 2012
genr a_r_tar=a_r_tar(-1)
genr a_socbr=a_socbr(-1)*(1+txq)/(1+txn)
genr a_socb=a_socbr*a_popt*a_pcoh

'     We recompute values over the full period

smpl @all
genr a_subs=a_r_subs*a_qv 
genr a_tar=a_r_tar*a_mv

'     Th margins

genr a_marg=(a_qv*(1-a_r_oit+a_r_subs)-a_wagef*(1+a_r_scf))

'      Assumptions on household revenue linked to production (revq) and not (revx)
 
genr a_revx=0.1*a_gdpv    '  *****pb : no measure of non wage revenue
genr a_revq=0.7*a_marg     '  *****pb : no measure of non wage revenue

'      Household total revenue

genr a_hi =a_wage-a_scw+a_socb+a_revx+a_revq+a_rem 

'     The income tax rate

genr a_r_ict=a_ict/a_hi    '    *****pb : only global tax on revenue 

'      Retro and extra polations

smpl 2012 2012
genr a_r_ih=a_r_ih(-1)
genr a_r_ict=a_r_ict(-1)
smpl @first 1999
genr a_r_ict=@elem(a_r_ict,"2000")
genr a_r_tar=@elem(a_r_tar,"2000")

'      We recompute the values

smpl @all
genr a_ict=a_r_ict*a_hi
genr a_tar=a_r_tar*a_mv
genr a_hdi=a_hi-a_ict
genr a_hrdi=a_hdi/a_pcoh
genr a_sr=1-a_coh/(a_hrdi)
genr a_r_revx=a_revx/a_pfd
genr a_r_revq=a_revq/a_qv
genr a_wageg=a_wr*a_lg       '   ****rem : l_g not available 
genr a_r_ih=a_ih/a_hrdi

'    rates

genr a_r_scg=  a_r_scf
scalar a_r_oit0=@elem(a_r_oit,"2005")

'----------------------------------------------------
'     external trade
'----------------------------------------------------

genr a_r_tarx=0
scalar a_r_tarx0=@elem(a_r_tarx,"2005")
scalar a_r_tar0=@elem(a_r_tar,"2005")

'     Foreign price and foreign demand

genr a_ppx=v_NY_GDP_MKTP_CD/v_NY_GDP_MKTP_KD   '    rem***** look for better later 
genr a_wd =v_NE_IMP_GNFS_KD   '    rem***** look for better later  

'      Trade ratios

genr a_rcvol=a_x/a_m
genr a_rcval=a_xv/a_mv
genr a_ttrad=a_px/a_pm
genr a_trb=a_xv-a_mv

'       Interests

genr a_nixs=v_dt_int_dstc_cd*a_ern
genr a_nixl=v_dt_int_dlxf_cd*a_ern  
genr a_nix=a_nixs+a_nixl
genr a_nixd=0.5*a_nix   '  *****rem : separating local and foreign currencies
genr a_nixx=0.5*a_nix   '  *****rem : separating local and foreign currencies
genr a_NIXD_ec=(a_NIXD-(a_NIXD(-1)*a_IRM/a_IRM(-1)-a_IR/100*0.5*a_TRB))/(a_xv+a_mv)
genr a_NIXX_ec=(a_NIXX-(a_NIXX(-1)*a_IRMX/a_IRMX(-1)*(a_er/a_er(-1))-a_IRX/100*0.5*a_TRB))/(a_xv+a_mv)
genr a_fcapx=a_trb-a_nix

'      Price and competitiveness

genr a_PMT=a_PM*(1+a_r_tar)/(1+a_r_tar0)
genr a_compm=a_pmt/a_pp
genr a_COMPX=a_PX*(1+a_r_tarx)/(1+a_r_tarx0)/(a_PPX*a_ER)

'--------------------------------------------------
'      firms account
'--------------------------------------------------

genr a_rmarg =a_marg / a_qv
genr a_rprob = a_marg/(a_pfd*a_k(-1)) 
genr a_r_ifp=a_ifp/(a_marg-a_revq)  

'    We retropolate the tax on profits
  
smpl @first 1999
genr a_r_ifp=@elem(a_r_ifp,"2000")
smpl 2012 2012
genr a_r_ifp=a_r_ifp(-1)
smpl @all
genr a_ifp=a_r_ifp*(a_marg-a_revq)

'     The interests paid

smpl 1991 1991
genr a_nif=(-a_marg+a_revq+a_ifp)*0.05
smpl 1992 2013
genr a_fcapf1=a_marg-a_revq-a_ifp-a_pip*a_ip-a_pfd*a_ic
genr a_nif=a_nif(-1)*a_irm/a_irm(-1)-a_fcapf1

'      Balances

smpl 1960 2013
genr a_prof=a_marg-a_revq-a_ifp-a_nif
genr a_rprof=a_prof/(a_pfd*a_k(-1)) 
genr a_fcapf=a_prof-a_pip*a_ip-a_pfd*a_ic
genr a_i=a_ip+a_ih+a_ig
genr a_fdxr=(a_fd-(a_COH+a_IP+a_IH+a_IC+a_cog+a_IG))/a_q 
genr a_fcapf=a_prof-a_pip*a_i-a_pfd*a_ic 
genr a_nif_er=(a_nif-(a_NIF(-1)*a_IRM/a_IRM(-1)-a_IR/100*a_FCAPF))/a_qv 

'------------------------------------------
'     Budget elements
'------------------------------------------

genr a_fcapg=-v_fs_ast_cgov_gd_zs*a_gdpv/100  '   *****rem : ????
genr a_r_oit=a_oit/(a_qv-a_oit)
genr a_nig=v_gc_xpn_intp_cn/100

'    The intersts paid

smpl 1991 1991
genr a_nig=0
smpl 1992 @last
genr a_nig=a_nig(-1)*a_irm/a_irm(-1)-a_ir/100*a_fcapg
smpl @all

'      Various elements

'    The wage rate is the same as firms'

genr a_wg=a_wr

'      Social contributions

genr a_scg=a_wg*a_r_scf


genr a_revg=a_ict+a_oit+a_vat+a_scf+a_scg+a_tar+a_scw+a_ifp
genr a_expg=a_revg-a_fcapg
genr a_dfgv=a_igv
genr a_r_expg=(a_EXPG-(a_FDGV+a_WAGEG+a_SUBS+a_SOCB+a_NIG+a_Scg))/a_Qv 

'      Additional potential residuals

genr a_r_revg=0
genr a_r_recg=0

'     Balances

genr a_expg=a_revg-a_fcapg
genr a_fcapgp=100*a_fcapg/a_gdpmv
genr a_nig_er=(a_nig-(a_nig(-1)*a_irm/a_irm(-1)-a_ir/100*a_fcapg))/a_qv 

'      These elements will come from estimations
'       Defining them will allow to create the groups of model variables

genr a_cost=na
genr a_costw=na
genr a_lpt=na

wfsave data_afs


