'
'===========================================
'       This program performs simulations over the future
     
'       Behaviors can be changed
'       Assumptions are set0
'       Endogenous are initialized
'       A base simulation is produced
'       Assumptions are shocked 
'           and the consequences measured

'===========================================

'      We set the directory

cd "c:\users\jean louis brillet\documents\eviews\book_africa\afsud"

'    We define the output file as proj_1.rtf

output(r) proj_afs

'     We define the list of excluded variables
'     This allows to exogeneize elements
'     It is only useful in case of convergence or property problems

%exclude=""

'      We copy the original mod_afs file into a forecast file called proj_1

'
close model_afs
close proj_afs
open model_afs
save proj_afs

'   Now we work on the future

'   We copy the page under a new name

pageselect model
pagecopy(page=forecast)

'     We extend the period to 2100

pagestruct(end=2100) * 

'     We define long-term growth rates 
'     Actually they will be applied to Dlogs (the same to the first order)
'     as we shall see later


scalar txq=0.035
scalar txn=0.01
scalar txp=0.050

'==========================================================
'     Setting the assumptions for the exogenous
'==========================================================

'      The above values will be applied to the Dlogs 
'       instead of being used as growth rates 

'       The reason quite technical (we are in a study phase)
'        It makes it easier to observe convergence to a steady state path 
'        (in particular visually)
'        if the dimension of the variable is a combination of basic ones
'        for instance for values (price+quantity) and wage rates (price+quantity-population)

'        A combination of "round" dlogs is a round dlog
'        which is not exactly true for growth rates

'        However for actual forecasts one can prefer reverting to growth rates
'        One just has to replace "dlog" by "@pch" 
'        in the following formulas

	'   Constant values : Dlog=0

smpl @all 

smpl 2013 2100
for %1 COH_EC ERX FDXR  K_EC CI_EC IR_ER IRL_ER IRMX IRSR IRST IRSX IRX LF_EC  M_EC NIF_ER NIG_ER PK PM_EC POPAC_EC PQ_EC PX_EC R_EXPG R_ICT R_IFP R_OIT R_PCOH R_PCOG R_PI R_PIG R_REVG R_REVQ R_SCF R_SCG R_SCW R_SUBS R_TAR R_TARX R_VAT RDEP TC URD  WR_EC X_EC IRM_ER NIXD_EC NIXX_EC R_IH R_LW R_PIP IC_EC IP_EC fcapf_er prof_er res_fdv
genr {%1}={%1}(-1)
next

	'  Variables at constant prices : Dlog=txq

for %1  COG   IG   R_REVX  wd
genr {%1}={%1}(-1)*(1+txq)
next

	'  Populations : Dlog=txn

for %1 LG POP1564 POP
genr {%1}={%1}(-1)*(1+txn)
next

	'  Prices : Dlog=txp

for %1  PPX 
genr {%1}={%1}(-1)*(1+txp)
next

	'  Values : Dlog=txp+txq

for %1  REMX 
genr {%1}={%1}(-1)*(1+txp)*(1+txq)
next

'            Purchasing power per head : Dlog=txp-txn

for %1   SOCBR
genr {%1}={%1}(-1)*(1+txq)/(1+txn)
next

'            The time trend

genr t=t(-1)+1

'             Now we give values to the endogenous
'             There are two main reasons

'             1 - This gives an alternate starting point for the solution algorithms
'              Sometimes this starting point is more efficient
'              One can just check

'             2 - This allows to make a residual check on the future
'              which is useful to check that :
'              using the exogenous assumptions 
'              applying the formula provides a steady state path
'              with the same growth rate as the variable it computes

'              When the condition is met for all equations
'              a steady state path exists
'              and will be reached provided the process is converging

'              A difference can come from :
'              - wrong dimensions in the assumptions
'              - non homogenous formulas
'              - wrong initialization of endogenous (not a real problem)

smpl 2013 2100
 
'        Constant values : Dlog=0

for %1   COMPM COMPX ER  FCAPGP IR IRL IRM IRS RCVAL RCVOL RES_WR  RMARG RPROB RPROF TTRAD UNR  UR
genr {%1}={%1}(-1)
next

'       Variables at constant prices : Dlog=txq

for %1  CAP COH  FD HRDI I IP IH CI K  M  Q  X GDPM IC TD FDL
genr {%1}={%1}(-1)*(1+txq)
next

'       Populations : Dlog=txn

for %1 LFD  LF LW LS LT   POPAC UN  popt
genr {%1}={%1}(-1)*(1+txn)
next

'      Deflators : Dlog = txp

for %1    COST PCOG PCOH PFD PFDXT PPI PIG PM PMT  PP PQ PX UWC PGDPM PIP COSTW PFDL
genr {%1}={%1}(-1)*(1+txp) 
next

'       Variables at current prices : Dlog = txp+txq

for %1 COGV  EXPG FCAPF FCAPG FCAPX FDGV HDI HI ICT IFP IGV MARG MV NIF NIG NIX NIXL NIXX OIT PROF GDPMV QV  REVG REVQ REVX  SCF SCG SCW SOCB SUBS TAR TRB  VAT XV  NIXD WAGE WAGEF WAGEG REM FDV FDLV
genr {%1}={%1}(-1)*(1+txp)*(1+txq)
next

'       Variables at current prices  per head : Dlog=txp+txq-txn

for %1 WR  
genr {%1}={%1}(-1)*(1+txp)*(1+txq)/(1+txn)
next

'      Variables at constant prices  per head : Dlog=txp+txq-txn

for %1 LP LPT RELC
genr {%1}={%1}(-1)*(1+txq)/(1+txn)
next 

'==========================================================
'     Solving the model on the future (basic simulation)

'==========================================================

'      Now we solve the model on the future
'      until 2100
'      using the basic assumptions

'       The scenario is "scenario 1"
'       The suffix is "_b"
'       The convergence criterion is 10-6 
'                   (relative difference from an iteration to the next)
'        The maximum number of iterations is 1001
'                    giving a special number can help to associate a failure message
'                    to a specific solve statement'               
'        The exclude statement states that all endogenous will be computed
'                    it cancels any previous exclusions
'                    which may remain from previous simulations of "Scenario 1"

smpl 2012 2100 
_mod_afs.solveopt(n=t,m=1000,c=1e-6,o=b,d=f )
_mod_afs.scenario "scenario 1"
_mod_afs.append assign @all _c
_mod_afs.exclude {%exclude}  '  The list is empty now
smpl 2012 2100
solve(n=t,m=1001,c=1e-6,o=b,d=f ) _mod_afs 


for !i=1 to _g_vendog.@count
%1=_g_vendog.@seriesname(!i)
genr dc_{%1}={%1}-{%1}_c
genr pc_{%1}=100*dc_{%1}/({%1}+({%1}=0))
next 

'         Now we compute the growth rates
'         or rather here the dlogs

'         We compute the ratio of the present to the previous Value
'         for each endogenous
'         If it is positive we take the logarithm to get the Dlog
'         otherwise we give the value "na"
'         This gives the same result as a direct computation
'          but avoids the error messages
'             Now we do the same for the initialization values
'             and compute the difference on the growth rates

for !i=1 to _g_vendog.@count
%st1=_g_vendog.@seriesname(!i)
smpl 2013 2100
series {%st1}_tc=100*({%st1}_c-{%st1}_c(-1))/({%st1}_c(-1)+({%st1}_c(-1)=0))  
series {%st1}_tc0=100*({%st1}-{%st1}(-1))/({%st1}(-1)+({%st1}(-1)=0))  
series {%st1}_DTc={%st1}_tc-{%st1}_tc0
next  

'     Now we solve the model on the future using dynamic simulations

smpl 2013 2100   
genr pq_ec=pq_ec+0.01
solve(n=t,m=1001,c=1e-6,o=g,d=d,i=p ) _mod_afs 
_mod_afs.solveopt(n=t,m=1000,c=1e-6,o=g,d=d,i=p )
_mod_afs.scenario "scenario 1"
_mod_afs.append assign @all _b
_mod_afs.exclude {%exclude}
_mod_afs.override    
solve(n=t,m=1001,c=1e-6,o=b,d=d ) _mod_afs 


'         Now we compute the growth rates
'         or rather here the dlogs

'         We compute the ratio of the present to the previous value
'         for each endogenous
'         If it is positive we take the logarithm to get the Dlog
'         otherwise we give the value "na"
'         This gives the same result as a direct computation
'          but avoids the error messages
'             Now we do the same for the initialization values
'             and compute the difference on the growth rates

for !i=1 to _g_vendog.@count
%st1=_g_vendog.@seriesname(!i)
smpl 2013 2100
series {%st1}_tc=100*({%st1}_b-{%st1}_b(-1))/({%st1}_b(-1)+({%st1}_b(-1)=0))  
series {%st1}_tc0=100*({%st1}-{%st1}(-1))/({%st1}(-1)+({%st1}(-1)=0))  
series {%st1}_DTC={%st1}_tc-{%st1}_tc0
next 

group g_table GDPM_tc FD_tc ip_tc i_tc coh_tc M_tc X_tc  100*RCVOL_b CAP_tc UR_b*100 PGDPM_tc pX_tc PM_tc PCOH_tc  pp_TC wr_tc COMPX_tc COMPM_tc Lf_tc LT_tc  UNR_b  
smpl 2013 2025
 
if @isobject("__proj") then
delete __proj
endif

show(t) g_table
freeze(__proj) g_table
__proj.deleterow(2)
__proj.insertrow(2)
__proj.insertrow(13)
__proj.insertrow(22) 
__proj.setjust(A1:A25)left
__proj.setjust(A1:N1) center
__proj.setwidth(A) 25
__proj.setwidth(B:N) 6.5
__proj.setformat(B2:N25) f.2
__proj.setlines(A1:N25) +o
__proj.setlines(A1:N1) +b
__proj.setlines(A12:N12) +b
__proj.setlines(A21:N21) +b
__proj.setlines(A25:N25) +b 
__proj.setfont(A2) +b
__proj.setfont(A13) +b
__proj.setfont(A22) +b 

__proj(1,1)=""

__proj(2,1)="Real equlibrium"
__proj(3,1)="GDP"
__proj(4,1)="Final demand"
__proj(5,1)="Productive Investment"
__proj(6,1)="Total Investment"
__proj(7,1)="Household Consumption"
__proj(8,1)="Imports"
__proj(9,1)="Exports"
__proj(10,1)="Export-import ratio"
__proj(11,1)="Productive capacity"
__proj(12,1)="Rate of use (*)"
__proj(13,1)="Deflators"
__proj(14,1)="GDP  "
__proj(15,1)="Exports  "
__proj(16,1)="Imports  "
__proj(17,1)="Consumer price index"
__proj(18,1)="Production"
__proj(19,1)="Wage rate"
__proj(20,1)="Export competitiveness"
__proj(21,1)="Import competitiveness"
__proj(22,1)="Employment"
__proj(23,1)="Firms employment"
__proj(24,1)="Total employment"
__proj(25,1)="Unemployment rate (*)" 
__proj.setindent(A) 4

close g_table
show __proj  

'       We save the workfile

smpl 2013 2100
save proj_afs.wf1


