'
'===========================================
'       This program performs simulations over the future
     
'       Behaviors can be changed
'       Assumptions are set0
'       Endogenous are initialized
'       A base simulation is produced
'       Assumptions are shocked 
'           and the consequences measured

'===========================================

'      We set the directory

cd "c:\users\jean louis brillet\documents\eviews\book_africa2\afsud"

'    We define the output file as proj_1.rtf

output(r) proj_afs

%exclude=""

'      We copy the original mod_afs file into a forecast file called proj_1

'
close model_afs
close proj_afs
open model_afs
save proj_afs

'   Now we work on the future

'   We copy the page under a new name

pageselect model
pagecopy(page=forecast)

'     We extend the period to 2100

pagestruct(end=2100) * 

'     We define long-term growth rates 
'     Actually they will be applied to Dlogs (the same to the first order)
'     as we shall see later


scalar txq=0.035
scalar txn=0.01
scalar txp=0.050

'========================================
'       Changing elements in estimated equations
'========================================

'      We will show how to modify equations
'      taking the example of capital

'    We will do it also for the value added deflator, the wage rate, imports and exports

'      First we estimate the equation as usual
'      but we add a "1" to its usual name

'smpl 1962 2004
'genr k_ec=0
'smpl 1962 2003
'equation _eq_k1.ls(p) dlog(k)=c_k(1)*dlog(k(-1))+0.50*c_k(2)*(q-q(-4))/q(-4)-c_k(2)*(urd-ur)/ur+c_k(4)*@movav(rprob,3)+c_k(5)*((t-2013)*(t<=2013))+c_k(6)   +k_ec 

'    Now we create a vector of parameters
'    equiVent to the vector of coefficients
'    but with "p" instead of "c"

'vector(10) p_k

'     We transfer the estimated values except the constant

'p_k(1)=c_k(1)
'p_k(2)=c_k(2)
'p_k(3)=c_k(2)
'p_k(4)=c_k(4)
'p_k(5)=c_k(5)

'      We reproduce the equation
'       with the original name
'       but some coefficients are replaced by vector elements
'       (not the constant)

'      We estimate the equation and compute the residual

'       As written, the simulated equation will work in the same way as before
'       but we can fix the value of any set of coefficients
'       by replacing "c" by "p" and giving a value as above
'       the remaining coefficients will be estimated

'       This can apply to one or several coefficients
'        but not to the constant
'        as EViews requires at least one coefficient to estimate

'equation _eq_k.ls(p) dlog(k)=p_k(1)*dlog(k(-1))+0.50*p_k(2)*(q-q(-4))/q(-4)-p_k(2)*(urd-ur)/ur+p_k(4)*@movav(rprob,3)+p_k(5)*((t-2013)*(t<=2013))+c_k(6)+k_ec 
'genr k_ec=resid

'       Forecasting the residuals for 2004 is done as usual

'for !i=1 to 4
'smpl 2004 2004 if (t=2004+(!i-1)/4)
'_eq_k.forecast(d) _z
'genr k_ec=dlog(k)-_z
'next
'_mod_afs.merge _eq_k 
' *********************************************************************

'    Changing the estimated formulas


'---  estimating capacity -----------------------------------------------

smpl 1996 2012
genr cap=q
coef(10) c_cap
vector(10) p_cap 
p_cap(1)=c_cap(1) 
p_cap(3)=c_cap(3)  
equation _eq_cap.ls(p) log(cap)=(1-p_cap(1))*log(k(-1))+p_cap(1)*log(lf)+c_cap(2)+p_cap(3)*(t-2012)*(t<=2012)+p_cap(1)*log((1+txq)/(1+txn))*(t-2012)*(t>=2012)

genr log(ur)=resid
genr cap=q/ur

'---  estimating investment -----------------------------------------------

smpl 1980 2012  
coef(10) c_ip
vector(10) p_ip 
genr ip_ec=0
p_ip(1)=c_ip(1)
p_ip(2)=c_ip(2)
p_ip(3)=0.05

equation _eq_ip.ls(p) ip/k(-1)=p_ip(1)*ip(-1)/k(-2)+p_ip(2)*@pch(q)+p_ip(3)*log(ur)+c_ip(4)+ip_ec
genr ip_ec=resid

'---  estimating employment -----------------------------------------------

'    We do not allow changing the formulation of the productivity trend.
 
coef(10) c_lf
vector(10) p_lf
smpl @first 2012 
genr lf_ec=0 
p_lf(1)=c_lf(1)
p_lf(2)=c_lf(2)
equation _eq_lf.ls(p) dlog(lf)=p_lf(1)*dlog(lfd)+p_lf(2)*log(lfd(-1)/lf(-1))+c_lf(3)+lf_ec
genr lf_ec=resid

'---  estimating the change in inventories -----------------------------------------------

'     We have to reestimate the equation coefficients as there is no constant term

show err_ic
coef(10) c_ic
vector(10) p_ic
smpl 1962 2012
genr ic_ec=0
smpl 1962 2012
  
equation _eq_ic.ls(p) ic/q(-1)=c_ic(1)*c_ic(2)*@pchy(q)+(1-c_ic(1))*ic(-1)/q(-2)+ic_ec 
genr ic_ec=resid

 

'    ---- estimating the actual work force ------------------------------------------------------

show err_popac
coef(10) c_popac
vector(10) p_popac

'      Special case : we want to set the value of a coefficient and estimate the rest

'      We create a normal vector in the same way as coefficients
'       with "p" instead of "c"

'      We just have to replace "c" by "p" in the equation
'      and give our value to the corresponding "p" element

'      This makes it easy to switch the definition

'      Here this applies to the third coefficient
'      with the value 0.6
 
smpl 1962 2012
genr popac_ec=0
smpl 1996 2012 
p_popac(1)=c_popac(1)
p_popac(2)=c_popac(2)
p_popac(3)=c_popac(3)
p_popac(4)=c_popac(4)
equation _eq_popac.ls(p) d(popac)/pop1564(-1)=c_popac(1)*d(lt)/pop1564(-1)+c_popac(2)*d(pop1564)/pop1564(-1)-c_popac(3)*(popac(-1)/pop1564(-1)-c_popac(4)*lt(-1)/pop1564(-1)-c_popac(5))+popac_ec
genr popac_ec=0

'    ----------------------------------------------------------

'    estimating the GDP deflator

show err_pq
smpl 1962 2012
scalar c_cost=0.05
genr cost=(wr*lf*(1+r_scf)+c_cost*pip*k(-1))/q
genr costw=(wr*lf*(1+r_scf))/q
coef(10) c_pq
vector(10) p_pq
genr pq_ec=0
smpl 1962 2012 
p_pq(1)=0.75
p_pq(2)=0.30
p_pq(3)=0.20
equation _eq_pq.ls(p) dlog(pq)=c_pq(1)*dlog(costw)+p_pq(2)*dlog(ur)-p_pq(3)*(log(pq(-1)/costw(-1))-p_pq(2)*log(ur(-1)))+c_pq(5)+pq_ec
genr pq_ec=resid 

'    ----- estimating the wage rate -----------------------------------------------------
 

show err_wr 
coef(10) c_wr
vector(10) p_wr 
 
smpl 1962 2012
genr wr_ec=0 
smpl 1962 2012 

p_wr(1)=c_wr(1)
p_wr(2)=-0.15
p_wr(3)=-0.10
p_wr(4)=0.50 
equation _eq_wr.ls(p) dlog(wr)=p_wr(1)*dlog(pcoh)+p_wr(2)*log(unr)+p_wr(3)*(log(costw(-1))-p_wr(4)*log(pcoh(-1))-(1-p_wr(4))*log(pq(-1)))+c_wr(5)+wr_ec 
genr wr_ec=resid 

'    ----------------------------------------------------------


'    estimating the import price

coef(10) c_pm
vector(10) p_pm
smpl 1962 2012
genr pm_ec=0
smpl @all 

p_pm(1)=0.2
p_pm(2)=0.8
p_pm(3)=0.50
p_pm(4)=0.20
p_pm(5)=c_pm(5)
equation _eq_pm.ls(p) dlog(pm)=p_pm(1)*dlog(pp)+p_pm(2)*dlog(ppx*er)-p_pm(3)*(log(pm(-1))-p_pm(4)*log(pp(-1))-(1-p_pm(4))*log(ppx(-1)*er(-1)))+p_pm(5)*(t-2012)*(t<=2012)+c_pm(6) +pm_ec
 
genr pm_ec=resid 

'    ----------------------------------------------------------


'    estimating the export price


show err_px
coef(10) c_px
vector(10) p_px
smpl @all
genr px_ec=0 

p_px(1)=0.60
p_px(2)=0.40
p_px(3)=0.50
p_px(4)=0.80
p_px(5)=c_px(5)
equation _eq_px.ls(p) dlog(px)=p_px(1)*dlog(pp)+p_px(2)*dlog(ppx*er)-p_px(3)*(log(px(-1))-p_px(4)*log(pp(-1))-(1-p_px(4))*log(ppx(-1)*er(-1)))+p_px(5)*(t-2012)*(t<=2012)+c_px(6)+px_ec
genr px_ec=resid 

'    ----------------------------------------------------------

'    estimating household consumption

show err_coh
coef(10) c_coh
vector(10) p_coh
smpl 1962 2012
genr coh_ec=0
smpl 1996 2012
 
p_coh(2)=c_coh(2)
p_coh(3)=c_coh(3)
p_coh(4)=c_coh(4)
p_coh(5)=c_coh(5)
p_coh(6)=c_coh(6)
p_coh(7)=c_coh(7)

equation _eq_coh.ls(p) dlog(coh)=c_coh(1)+p_coh(2)*(t-2012)*(t<=2012)+p_coh(3)*dlog(hrdi)+p_coh(4)*log(coh(-1)/hrdi(-1))+p_coh(5)*d(unr)+p_coh(6)*(irs-100*@pch(pcoh))+coh_ec
genr coh_ec=resid 


'    ----------------------------------------------------------

'    estimating imports

show err_m
coef(10) c_m
vector(10) p_m
smpl 1962 2012
genr m_ec=0
smpl 1962 2012 

p_m(1)=p_m(1)
p_m(2)=c_m(2)
p_m(3)=c_m(3)
p_m(5)=c_m(5) 
equation _eq_m.ls(p)  dlog(m)=p_m(1)*dlog(td)+c_m(2)*log(compm)+c_m(3)*log(ur)+c_m(4)+c_m(5)*log(m(-1)/td(-1))+m_ec
genr m_ec=resid 

'    with UR in W and PEX 0.5


'    ----------------------------------------------------------

'    estimating exports

show err_x
coef(10) c_x
vector(10) p_x
smpl 1962 2012
genr x_ec=0
smpl 1962 2012 

p_x(1)=c_x(1)
p_x(2)=c_x(2)
p_x(3)=c_x(3)
p_x(4)=c_x(4)
p_x(6)=c_x(6)
equation _eq_x.ls(p) dlog(x)=p_x(1)*dlog(wd)+p_x(2)*log(x(-1)/wd(-1))+p_x(3)*log(ur)+p_x(4)*log(compx)+c_x(5)+p_x(6)*(t-2012)*(t<=2012)+x_ec
genr x_ec=resid 

'      We recompile the model to take into account the changes

_mod_afs.update

'==========================================================
'     Setting the assumptions for the exogenous
'==========================================================

'      The above values will be applied to the Dlogs 
'       instead of being used as growth rates 

'       The reason quite technical (we are in a study phase)
'        It makes it easier to observe convergence to a steady state path 
'        (in particular visually)
'        if the dimension of the variable is a combination of basic ones
'        for instance for values (price+quantity) and wage rates (price+quantity-population)

'        A combination of "round" dlogs is a round dlog
'        which is not exactly true for growth rates

'        However for actual forecasts one can prefer reverting to growth rates
'        One just has to replace "dlog" by "@pch" 
'        in the following formulas

	'   Constant values : Dlog=0

smpl @all 

smpl 2013 2100
for %1 COH_EC ERX FDXR  K_EC CI_EC IR_ER IRL_ER IRMX IRSR IRST IRSX IRX LF_EC  M_EC NIF_ER NIG_ER PK PM_EC POPAC_EC PQ_EC PX_EC R_EXPG R_ICT R_IFP R_OIT R_PCOH R_PCOG R_PI R_PIG R_REVG R_REVQ R_SCF R_SCG R_SCW R_SUBS R_TAR R_TARX R_VAT RDEP TC URD  WR_EC X_EC IRM_ER NIXD_EC NIXX_EC R_IH R_LW R_PIP IC_EC IP_EC fcapf_er prof_er res_fdv
genr {%1}={%1}(-1)
next

	'  Variables at constant prices : Dlog=txq

for %1  COG   IG   R_REVX  
genr {%1}={%1}(-1)*(1+txq)
next

'    Special case for world demand 

genr wd=wd(-1)*(1+txq)

	'  Populations : Dlog=txn

for %1 LG POP1564 POP
genr {%1}={%1}(-1)*(1+txn)
next

	'  Prices : Dlog=txp

for %1  PPX 
genr {%1}={%1}(-1)*(1+txp)
next

	'  Values : Dlog=txp+txq

for %1  REMX 
genr {%1}={%1}(-1)*(1+txp)*(1+txq)
next

'            Purchasing power per head : Dlog=txp-txn

for %1   SOCBR
genr {%1}={%1}(-1)*(1+txq)/(1+txn)
next

'            The time trend

genr t=t(-1)+1

'             Now we give values to the endogenous
'             There are two main reasons

'             1 - This gives an alternate starting point for the solution algorithms
'              Sometimes this starting point is more efficient
'              One can just check

'             2 - This allows to make a residual check on the future
'              which is useful to check that :
'              using the exogenous assumptions 
'              applying the formula provides a steady state path
'              with the same growth rate as the variable it computes

'              When the condition is met for all equations
'              a steady state path exists
'              and will be reached provided the process is converging

'              A difference can come from :
'              - wrong dimensions in the assumptions
'              - non homogenous formulas
'              - wrong initialization of endogenous (not a real problem)

smpl 2013 2100
 
'        Constant values : Dlog=0

for %1   COMPM COMPX ER  FCAPGP IR IRL IRM IRS RCVAL RCVOL RES_WR  RMARG RPROB RPROF TTRAD UNR  UR
genr {%1}={%1}(-1)
next

'       Variables at constant prices : Dlog=txq

for %1  CAP COH  FD HRDI I IP IH CI K  M  Q  X GDPM IC TD FDL
genr {%1}={%1}(-1)*(1+txq)
next

'       Populations : Dlog=txn

for %1 LFD  LF LW LS LT   POPAC UN  popt
genr {%1}={%1}(-1)*(1+txn)
next

'      Deflators : Dlog = txp

for %1    COST PCOG PCOH PFD PFDXT PPI PIG PM PMT  PP PQ PX UWC PGDPM PIP COSTW PFDL
genr {%1}={%1}(-1)*(1+txp) 
next

'       Variables at current prices : Dlog = txp+txq

for %1 COGV  EXPG FCAPF FCAPG FCAPX FDGV HDI HI ICT IFP IGV MARG MV NIF NIG NIX NIXL NIXX OIT PROF GDPMV QV  REVG REVQ REVX  SCF SCG SCW SOCB SUBS TAR TRB  VAT XV  NIXD WAGE WAGEF WAGEG REM FDV FDLV
genr {%1}={%1}(-1)*(1+txp)*(1+txq)
next

'       Variables at current prices  per head : Dlog=txp+txq-txn

for %1 WR  
genr {%1}={%1}(-1)*(1+txp)*(1+txq)/(1+txn)
next

'      Variables at constant prices  per head : Dlog=txp+txq-txn

for %1 LP LPT RELC
genr {%1}={%1}(-1)*(1+txq)/(1+txn)
next 

'==========================================================
'     Solving the model on the future (basic simulation)

'==========================================================

'      Now we solve the model on the future
'      until 2100
'      using the basic assumptions

'       The scenario is "scenario 1"
'       The suffix is "_b"
'       The convergence criterion is 10-6 
'                   (relative difference from an iteration to the next)
'        The maximum number of iterations is 1001
'                    giving a special number can help to associate a failure message
'                    to a specific solve statement'               
'        The exclude statement states that all endogenous will be computed
'                    it cancels any previous exclusions
'                    which may remain from previous simulations of "Scenario 1"

smpl 2012 2100 
_mod_afs.solveopt(n=t,m=1000,c=1e-6,o=b,d=f )
_mod_afs.scenario "scenario 1"
_mod_afs.append assign @all _d
_mod_afs.exclude {%exclude}
smpl 2012 2100
solve(n=t,m=1001,c=1e-6,o=b,d=f ) _mod_afs 


for !i=1 to _g_vendog.@count
%1=_g_vendog.@seriesname(!i)
genr dc_{%1}={%1}-{%1}_c
genr pc_{%1}=100*dc_{%1}/({%1}+({%1}=0))
next 

'         Now we compute the growth rates
'         or rather here the dlogs

'         We compute the ratio of the present to the previous Value
'         for each endogenous
'         If it is positive we take the logarithm to get the Dlog
'         otherwise we give the value "na"
'         This gives the same result as a direct computation
'          but avoids the error messages
'             Now we do the same for the initialization values
'             and compute the difference on the growth rates

for !i=1 to _g_vendog.@count
%st1=_g_vendog.@seriesname(!i)
smpl 2013 2100
series {%st1}_td=100*({%st1}_d-{%st1}_d(-1))/({%st1}_d(-1)+({%st1}_d(-1)=0))  
series {%st1}_tc0=100*({%st1}-{%st1}(-1))/({%st1}(-1)+({%st1}(-1)=0))  
series {%st1}_DTd={%st1}_td-{%st1}_tc0
next  

smpl 2013 2100   
genr pq_ec=pq_ec+0.01
solve(n=t,m=1001,c=1e-6,o=b,d=d ) _mod_afs 
_mod_afs.solveopt(n=t,m=1000,c=1e-6,o=b,d=d )
_mod_afs.scenario "scenario 1"
_mod_afs.append assign @all _b
_mod_afs.exclude {%exclude}
_mod_afs.override    
solve(n=t,m=1001,c=1e-6,o=b,d=d ) _mod_afs 


'         Now we compute the growth rates
'         or rather here the dlogs

'         We compute the ratio of the present to the previous value
'         for each endogenous
'         If it is positive we take the logarithm to get the Dlog
'         otherwise we give the value "na"
'         This gives the same result as a direct computation
'          but avoids the error messages
'             Now we do the same for the initialization values
'             and compute the difference on the growth rates

for !i=1 to _g_vendog.@count
%st1=_g_vendog.@seriesname(!i)
smpl 2013 2100
series {%st1}_tc=100*({%st1}_b-{%st1}_b(-1))/({%st1}_b(-1)+({%st1}_b(-1)=0))  
series {%st1}_tc0=100*({%st1}-{%st1}(-1))/({%st1}(-1)+({%st1}(-1)=0))  
series {%st1}_DTC={%st1}_tc-{%st1}_tc0
next 

group g_table GDPM_tc FD_tc ip_tc i_tc coh_tc M_tc X_tc  100*RCVOL_b CAP_tc UR_b*100 PGDPM_tc pX_tc PM_tc PCOH_tc  pp_TC wr_tc COMPX_tc COMPM_tc Lf_tc LT_tc  UNR_b  
smpl 2013 2025
 
if @isobject("__proj") then
delete __proj
endif

show(t) g_table
freeze(__proj) g_table
__proj.deleterow(2)
__proj.insertrow(2)
__proj.insertrow(13)
__proj.insertrow(22) 
__proj.setjust(A1:A25)left
__proj.setjust(A1:N1) center
__proj.setwidth(A) 25
__proj.setwidth(B:N) 6.5
__proj.setformat(B2:N25) f.2
__proj.setlines(A1:N25) +o
__proj.setlines(A1:N1) +b
__proj.setlines(A12:N12) +b
__proj.setlines(A21:N21) +b
__proj.setlines(A25:N25) +b 
__proj.setfont(A2) +b
__proj.setfont(A13) +b
__proj.setfont(A22) +b 

__proj(1,1)=""

__proj(2,1)="Real equlibrium"
__proj(3,1)="GDP"
__proj(4,1)="Final demand"
__proj(5,1)="Productive Investment"
__proj(6,1)="Total Investment"
__proj(7,1)="Household Consumption"
__proj(8,1)="Imports"
__proj(9,1)="Exports"
__proj(10,1)="Export-import ratio"
__proj(11,1)="Productive capacity"
__proj(12,1)="Rate of use (*)"
__proj(13,1)="Deflators"
__proj(14,1)="GDP  "
__proj(15,1)="Exports  "
__proj(16,1)="Imports  "
__proj(17,1)="Consumer price index"
__proj(18,1)="Production"
__proj(19,1)="Wage rate"
__proj(20,1)="Export competitiveness"
__proj(21,1)="Import competitiveness"
__proj(22,1)="Employment"
__proj(23,1)="Firms employment"
__proj(24,1)="Total employment"
__proj(25,1)="Unemployment rate (*)" 
__proj.setindent(A) 4

close g_table
show __proj  

'==========================================================
'     Solving the model on the future (shocked assumptions)
'==========================================================

'     Now we shall produce a set shocks (in the preafst case 7)

smpl 2000 2100

'    The group called shocks_v will contain the list of 7 shocked variables

group shocks_v erx r_vat r_tar r_tarx wd m_ec ig

'    The group called shocks_l will contain 7 letters associated to each shock
'     but the letters must be known as series 
'     as groups can contain only series

'     We create artificial series 
'      but only for the non-existing ones of course (not t or x or m.......)

delete f
for %1 ex vt tl tx wd im gd
if @isobject(%1)=0 then
genr {%1}=na
endif
next

'      We create the group

group shocks_l  ex vt tl tx wd im gd

'    Now we compute the additional change for each assumption, 
'    using the name of the variable
'    The shock will only start in 2006
'    to check that the difference comes only from the shock

'      1 - Shock g : +1 GDP point on Government demand

genr ig_gd=ig+.01*gdpm_b*(t>=2014)

'      2 - Shock r : 1% devaluation of the Euro

genr erx_ex=erx*(1+.01*(t>=2014))

'      3 - Shock t : -1 point on the VAT rate

genr r_vat_vt=r_vat-.01*(t>=2014)

'      4 - Shock f : -1 point on the local tariffs rate

genr r_tar_tl=r_tar-.01*(t>=2014)

'      5 - Shock y : -1 point on the foreign tariffs rate

genr r_tarx_tx=r_tarx-.01*(t>=2014)

'      6 - Shock w : +1% on World demand addressed to the country

genr wd_wd=wd*(1+.01*(t>=2014))

'      7 - Shock n : +1% on ex-ante imports

genr m_ec_im=m_ec+.01*(t=2014)-.01*(t>2014)*p_m(5)

'     The loop on the shocks

for !j=1 to  shocks_v.@count

smpl 2013 2100

'   We get the name of the shocked variable and the associated letter

%2=shocks_v.@seriesname(!j)
%3=shocks_l.@seriesname(!j)

output(r,o) var_{%3}

'    We set the solution suffix using the letter 
'    We control no endogenous is excluded from the simulation
'    We override the variable associated to the current shock
'    We solve the model

smpl 2013 2100

'    We solve the model

_mod_afs.scenario "scenario 1"
_mod_afs.append assign @all _{%3}
_mod_afs.exclude   {%exclude}
_mod_afs.override {%2}
solve(n=t,m=1000+!j,c=1e-6,o=b,d=d) _mod_afs

'   We compute the difference to the base simulation, in absolute and relative terms

for !i=1 to _g_vendog.@count
%st1=_g_vendog.@seriesname(!i)
series d{%3}_{%st1}={%st1}_{%3}-{%st1}_b
series p{%3}_{%st1}=100* d{%3}_{%st1}/({%st1}_b+ ({%st1}_b=0))
series dv_{%st1}=d{%3}_{%st1}
series pv_{%st1}=p{%3}_{%st1}
next

'   We create groups for variations for a specific list of important variables

group g_v{%3} P{%3}_PFD P{%3}_PM P{%3}_PX P{%3}_PQ P{%3}_WR P{%3}_FD P{%3}_gdpm P{%3}_X P{%3}_M P{%3}_I P{%3}_COH P{%3}_UR P{%3}_CAP  P{%3}_LF P{%3}_K P{%3}_UNR  D{%3}_FCAPGP P{%3}_RCVAL P{%3}_RCVOL P{%3}_TTRAD 

'   Or very important ones

group g_w{%3} P{%3}_FD P{%3}_gdpm P{%3}_X P{%3}_M   P{%3}_PQ  

'    We create a group for variations for all variables

group g_v2 pV_* dV_* 

'      We store all shocks in Excel files (2025 and 2100)
'      using the letter associated to the shock

smpl 2013 2025
write(t=xls) v2_{%3}.xls g_v2 
smpl 2013 2100
write(t=xls) w2_{%3}.xls g_v2  

alpha title_gd="Government demand"
alpha title_ex="the exchange rate"
alpha title_vt="the value added tax" 
alpha title_tl="shock on local tariffs"
alpha title_tx="shock on foreign tariffs"
alpha title_wd="shock on foreign quotas"
alpha title_im="shock on local quotas"  

alpha units_gd="+1 point of GDP"
alpha units_ex="+1 point of the rate"
alpha units_vt="-1 point of the rate"
alpha units_tl="-1 point of the rate"
alpha units_tx="+1% of ex ante world demand"
alpha units_wd="-1 point of the rate"
alpha units_im="+1% of ex ante imports "

%title=@elem(title_{%3},"2020")
%units=@elem(units_{%3},"2020")

smpl 2013 2025

'    Supply - demand graph
 
graph _gr_{%3}1.line P{%3}_fd P{%3}_gdpm P{%3}_x P{%3}_m P{%3}_pq   
_gr_{%3}1.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(Final demand)
_gr_{%3}1.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(GDP)
_gr_{%3}1.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(Exports)
_gr_{%3}1.setelem(4) symbol(4) lcolor(orange) lwidth(0.25) lpat(4) legend(Imports)
_gr_{%3}1.setelem(5) symbol(10) lcolor(purple) lwidth(0.25) lpat(5) legend(GDP deflator) 
_gr_{%3}1.legend position(botleft)
_gr_{%3}1.axis(left) grid
_gr_{%3}1.axis(bottom) grid 
_gr_{%3}1.addtext(t,font=12,x) {%title} : The supply - demand equilibrium  
_gr_{%3}1.addtext(l,font=11) in percentage 
_gr_{%3}1.addtext(r,font=10) shock : {%units}

print(l) _gr_{%3}1

close _gr_{%3}1 

'    Production

graph _gr_{%3}2.line P{%3}_q p{%3}_cap p{%3}_k p{%3}_lf p{%3}_ur
_gr_{%3}2.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(Value added)
_gr_{%3}2.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(Capacity)
_gr_{%3}2.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(Capital)
_gr_{%3}2.setelem(4) symbol(4) lcolor(orange) lwidth(0.25) lpat(4) legend(Employment)
_gr_{%3}2.setelem(5) symbol(10) lcolor(purple) lwidth(0.25) lpat(5) legend(Rate of use) 
_gr_{%3}2.legend position(botleft)
_gr_{%3}2.axis(left) grid
_gr_{%3}2.axis(bottom) grid 
_gr_{%3}2.addtext(t,font=12,x)  {%title} : The production elements 
_gr_{%3}2.addtext(l,font=11) in percentage
_gr_{%3}2.addtext(r,font=10) shock : {%units} 

print(l) _gr_{%3}2

close _gr_{%3}2


'    Ratios

graph _gr_{%3}3.line  p{%3}_relc p{%3}_k-p{%3}_lf   p{%3}_ur d{%3}_unr
_gr_{%3}3.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(Relative cost)
_gr_{%3}3.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(Capital-Labour ratio)
_gr_{%3}3.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(Rate of use)
_gr_{%3}3.setelem(4) symbol(4) lcolor(orange) lwidth(0.25) lpat(4) legend(Unemployment rate in points) 
_gr_{%3}3.legend position(botleft)
_gr_{%3}3.axis(left) grid
_gr_{%3}3.axis(bottom) grid 
_gr_{%3}3.addtext(t,font=12,x)  {%title} : The ratios 
_gr_{%3}3.addtext(l,font=11) in percentage
_gr_{%3}3.addtext(r,font=10) shock : {%units}  

print(l) _gr_{%3}3

close _gr_{%3}3

'    External trade 1

graph _gr_{%3}4.line p{%3}_xV p{%3}_mV p{%3}_rcVAL
_gr_{%3}4.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(Exports)
_gr_{%3}4.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(Imports)
_gr_{%3}4.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(Exports-Imports ratio) 
_gr_{%3}4.legend position(botleft)
_gr_{%3}4.axis(left) grid
_gr_{%3}4.axis(bottom) grid 
_gr_{%3}4.addtext(t,font=12,x)  {%title} : External trade at current prices  
_gr_{%3}4.addtext(l,font=11) in percentage
_gr_{%3}4.addtext(r,font=10) shock : {%units}  

print(l) _gr_{%3}4

close _gr_{%3}4


'    External trade 2

graph _gr_{%3}5.line p{%3}_rcvol p{%3}_ttrad p{%3}_rcVAL
_gr_{%3}5.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(At constant prices)
_gr_{%3}5.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(Terms of trade)
_gr_{%3}5.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(At constant prices) 
_gr_{%3}5.legend position(botleft)
_gr_{%3}5.axis(left) grid
_gr_{%3}5.axis(bottom) grid 
_gr_{%3}5.addtext(t,font=12,x)  {%title} : The exports - import ratios 
_gr_{%3}5.addtext(l,font=11) in percentage
_gr_{%3}5.addtext(r,font=10) shock : {%units}  

print(l) _gr_{%3}5

close _gr_{%3}5

'    Prices

graph _gr_{%3}6.line p{%3}_wr p{%3}_pfd p{%3}_pq p{%3}_px p{%3}_pm p{%3}_pp
_gr_{%3}6.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(Wage rate)
_gr_{%3}6.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(Consumption)
_gr_{%3}6.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(Value added)
_gr_{%3}6.setelem(4) symbol(4) lcolor(orange) lwidth(0.25) lpat(4) legend(Exports)
_gr_{%3}6.setelem(5) symbol(10) lcolor(purple) lwidth(0.25) lpat(5) legend(Imports) 
_gr_{%3}6.setelem(6) symbol(5) lcolor(gray) lwidth(0.25) lpat(6) legend(Production) 
_gr_{%3}6.legend position(botleft)
_gr_{%3}6.axis(left) grid
_gr_{%3}6.axis(bottom) grid 
_gr_{%3}6.addtext(t,font=12,x)  {%title} : The prices   
_gr_{%3}6.addtext(l,font=11) in percentage 
_gr_{%3}6.addtext(r,font=10) shock : {%units} 


graph _gr{%3}tot.merge _gr_{%3}1 _gr_{%3}2 _gr_{%3}3 _gr_{%3}4 _gr_{%3}5 _gr_{%3}6  
_gr{%3}tot.align(3,2,2)

 print(l) _gr_{%3}6

close _gr_{%3}6

group g_t{%3} p{%3}_GDPM p{%3}_FD p{%3}_ip p{%3}_i p{%3}_coh p{%3}_M p{%3}_X p{%3}_RCVOL p{%3}_CAP p{%3}_UR  p{%3}_PGDPM p{%3}_PX p{%3}_PM p{%3}_PCOH p{%3}_WR p{%3}_COMPX p{%3}_COMPM p{%3}_Lf p{%3}_LT d{%3}_UNR  100*d{%3}_RMARG 100*d{%3}_RPROB 100*d{%3}_expg/gdpmv_b 100*d{%3}_revg/gdpmv_b 100*d{%3}_fcapg/gdpmv_b
smpl 2013 2025
 
%tab="_TAB"+%3
if @isobject(%tab) then
delete %tab
endif

smpl 2014 2026
show(t) g_t{%3}
freeze({%tab}) g_t{%3}
{%tab}.deleterow(2)
{%tab}.insertrow(2)
{%tab}.insertrow(13)
{%tab}.insertrow(21)
{%tab}.insertrow(25)
{%tab}.insertrow(31)
{%tab}.setjust(A1:A30)left
{%tab}.setjust(A1:N1) center
{%tab}.setwidth(A) 25
{%tab}.setwidth(B:N) 5.5
{%tab}.setformat(B2:N30) f.2
{%tab}.setlines(A1:N30) +o
{%tab}.setlines(A1:N1) +b
{%tab}.setlines(A12:N12) +b
{%tab}.setlines(A20:N20) +b
{%tab}.setlines(A24:N24) +b
{%tab}.setlines(A30:N30) +b 
{%tab}.setlines(A1:A30) +r
{%tab}.setfont(A2) +b
{%tab}.setfont(A13) +b
{%tab}.setfont(A21) +b
{%tab}.setfont(A25) +b 

{%tab}(1,1)=""

{%tab}(2,1)="Real equlibrium"
{%tab}(3,1)="GDP"
{%tab}(4,1)="Final demand"
{%tab}(5,1)="Productive Investment"
{%tab}(6,1)="Total Investment"
{%tab}(7,1)="Household Consumption"
{%tab}(8,1)="Imports"
{%tab}(9,1)="Exports"
{%tab}(10,1)="Export-import ratio"
{%tab}(11,1)="Productive capacity"
{%tab}(12,1)="Rate of use (*)"
{%tab}(13,1)="Deflators"
{%tab}(14,1)="GDP  "
{%tab}(15,1)="Exports  "
{%tab}(16,1)="Imports  "
{%tab}(17,1)="Consumer price index"
{%tab}(18,1)="Wage rate"
{%tab}(19,1)="Export competitiveness"
{%tab}(20,1)="Import competitiveness"
{%tab}(21,1)="Employment"
{%tab}(22,1)="Firms employment"
{%tab}(23,1)="Total employment"
{%tab}(24,1)="Unemployment rate (*)"
{%tab}(25,1)="Balances"
{%tab}(26,1)="Margins rate (*)"
{%tab}(27,1)="Profits rate (*)" 
{%tab}(28,1)="Government expenditures (*)"
{%tab}(29,1)="Government revenue (*)" 
{%tab}(30,1)="Government balance  (*)" 
{%tab}(32,1)="(*) In GDP points" 
{%tab}.setindent(A) 4

print(l) {%tab}
close g_t{%3}
next

'       We save the workfile

smpl 2013 2100
save proj_afs.wf1


