'
'=======================================================
'       This program performs stochastic simulations over the future 
'       Residuals are drawn from a normal distribution
'       We can also introduce residuals on coefficients
'=======================================================

'      We set the directory

cd "c:\users\jean louis brillet\documents\eviews\book_africa2\afsud"

'    We define the output file as proj_afssto.rtf

output(r) proj_afssto

%exclude=""

'      We copy the original mod_afs file into a forecast file called proj_afssto

close model_afs
close proj_afssto.wf1
open model_afs
smpl  2000 2012
_mod_afs.append assign @all _s
_mod_afs.stochastic(f=0.50)
solve(n=t,m=1001,c=1e-6,o=b,d=d,s=a,r=5000) _mod_afs 
save proj_afssto.wf1

'   Now we work on the future

'   We copy the page under a new name

pageselect model
pagecopy(page=forecast)

'     We extend the period to 2050

pagestruct(end=2050) * 

'     We define long-term growth rates 
'     Actually they will be applied to Dlogs (the same to the first order)
'     as we shall see later

scalar txq=0.035
scalar txn=0.01
scalar txp=0.050

'==========================================================
'     Setting the assumptions for the exogenous
'========================================================== 

	'   Constant values : growth rate=0

smpl @all 

smpl 2013 2050
for %1 COH_EC ERX FDXR  K_EC CI_EC IR_ER IRL_ER IRMX IRSR IRST IRSX IRX LF_EC  M_EC NIF_ER NIG_ER PK PM_EC POPAC_EC PQ_EC PX_EC R_EXPG R_ICT R_IFP R_OIT R_PCOH R_PCOG R_PI R_PIG R_REVG R_REVQ R_SCF R_SCG R_SCW R_SUBS R_TAR R_TARX R_VAT RDEP TC URD  WR_EC X_EC IRM_ER NIXD_EC NIXX_EC R_IH R_LW R_PIP IC_EC IP_EC fcapf_er prof_er res_fdv
genr {%1}={%1}(-1)
next

	'  Variables at constant prices : Growth rate=txq

for %1  COG   IG   R_REVX  
genr {%1}={%1}(-1)*(1+txq)
next

'    Special case for world demand 

genr wd=wd(-1)*(1+txq)

	'  Populations : Growth rate=txn

for %1 LG POP1564 POP
genr {%1}={%1}(-1)*(1+txn)
next

	'  Prices : Growth rate=txp

for %1  PPX 
genr {%1}={%1}(-1)*(1+txp)
next

	'  Values : Growth rate=txp+txq

for %1  REMX 
genr {%1}={%1}(-1)*(1+txp)*(1+txq)
next

'            Purchasing power per head : Growth rate=txp-txn

for %1   SOCBR
genr {%1}={%1}(-1)*(1+txq)/(1+txn)
next

'            The time trend

genr t=t(-1)+1

'             Now we give values to the endogenous
'             There are two main reasons

'             1 - This gives an alternate starting point for the solution algorithms
'              Sometimes this starting point is more efficient
'              One can just check

'             2 - This allows to make a residual check on the future
'              which is useful to check that :
'              using the exogenous assumptions 
'              applying the formula provides a steady state path
'              with the same growth rate as the variable it computes

'              When the condition is met for all equations
'              a steady state path exists
'              and will be reached provided the process is converging

'              A difference can come from :
'              - wrong dimensions in the assumptions
'              - non homogenous formulas
'              - wrong initialization of endogenous (not a real problem)

smpl 2013 2050
 
'        Constant values : Growth rate=0

for %1   COMPM COMPX ER  FCAPGP IR IRL IRM IRS RCVAL RCVOL RES_WR  RMARG RPROB RPROF TTRAD UNR  UR
genr {%1}={%1}(-1)
next

'       Variables at constant prices : Growth rate=txq

for %1  CAP COH  FD HRDI I IP IH CI K  M  Q  X GDPM IC TD FDL
genr {%1}={%1}(-1)*(1+txq)
next

'       Populations : Growth rate=txn

for %1 LFD  LF LW LS LT   POPAC UN  popt
genr {%1}={%1}(-1)*(1+txn)
next

'      Deflators : Growth rate = txp

for %1    COST PCOG PCOH PFD PFDXT PPI PIG PM PMT  PP PQ PX UWC PGDPM PIP COSTW PFDL
genr {%1}={%1}(-1)*(1+txp) 
next

'       Variables at current prices : Growth rate = txp+txq

for %1 COGV  EXPG FCAPF FCAPG FCAPX FDGV HDI HI ICT IFP IGV MARG MV NIF NIG NIX NIXL NIXX OIT PROF GDPMV QV  REVG REVQ REVX  SCF SCG SCW SOCB SUBS TAR TRB  VAT XV  NIXD WAGE WAGEF WAGEG REM FDV FDLV
genr {%1}={%1}(-1)*(1+txp)*(1+txq)
next

'       Variables at current prices  per head : Growth rate=txp+txq-txn

for %1 WR  
genr {%1}={%1}(-1)*(1+txp)*(1+txq)/(1+txn)
next

'      Variables at constant prices  per head : Growth rate=txp+txq-txn

for %1 LP LPT RELC
genr {%1}={%1}(-1)*(1+txq)/(1+txn)
next 

'==========================================================
'     Solving the model on the future (basic simulation)

'==========================================================

'      Now we solve the model on the future
'      until 2050
'      using the basic assumptions

'       The scenario is "scenario 1"
'       The suffix is "_b"
'       The convergence criterion is 10-6 
'                   (relative difference from an iteration to the next)
'        The maximum number of iterations is 1001
'                    giving a special number can help to associate a failure message
'                    to a specific solve statement'               
'        The exclude statement states that all endogenous will be computed
'                    it cancels any previous exclusions
'                    which may remain from previous simulations of "Scenario 1"

'     First we produce a deterministic simulation
'     with residuals equal to the last value (see above)
 
_mod_afs.solveopt(n=t,m=1000,o=g,d=d,i=p )
_mod_afs.scenario "scenario 1"
_mod_afs.append assign @all _b
_mod_afs.exclude {%exclude}
_mod_afs.override   
smpl 2013 2050 
solve(n=t,m=1001,c=1e-6,o=b,d=d,i=p ) _mod_afs   

'      Now we start the stochastoc simulations

'      We initialize the random process

rndseed 1235

_mod_afs.scenario "scenario 1"

'      We produce the first simulation

'      s=a : we produce all results: 
'          q_b1m : the mean
'          q_b1l, q_b1h: the bounds of the 95% probability interval
'          q_b1s : the standard error

'     r=10000 : the number of replications
 
_mod_afs.solveopt(n=t,m=1000,o=g,d=d,s=a,i=p,r=10000) 
_mod_afs.append assign @all _b1
_mod_afs.exclude {%exclude}
_mod_afs.override 

'      c=f  (false): we do not consider the error from coefficients
'      p=stoc1: the page with the individual results
     
_mod_afs.stochastic(c=f,p=stoc1)     
_mod_afs.solve   

_mod_afs.solveopt(n=t,m=1000,o=g,d=d,s=a,i=p,r=10000) 
_mod_afs.append assign @all _b2
_mod_afs.exclude {%exclude}
_mod_afs.override 

'       c=t  (true): we introduce the coefficient error
'       p=stoc2 : the page with the individual results

_mod_afs.stochastic(c=t,p=stoc2)  
_mod_afs.solve 

show gdpm_b1s/gdpm_b1m  fd_b1s/fd_b1m  x_b1s/x_b1m  m_b1s/m_b1m  pq_b1s/pq_b1m
 

'       We save the workfile

smpl 2013 2050
save proj_afssto.wf1


