'
'===========================================
'       This program performs simulations over the future
     
'       Behaviors can be changed
'       Assumptions are set0
'       Endogenous are initialized
'       A base simulation is produced
'       Assumptions are shocked 
'           and the consequences measured

'===========================================

'      We set the directory

cd "c:\users\jean louis brillet\documents\eviews\book_africa2\afsud"

'    We define the output file as proj_afs.rtf

output(r) proj_afs

%exclude="" 

'      We copy the original mod_afs file into a forecast file called proj_1

'
close model_afs
close projfor21_afs
open model_afs
save projfor21_afs

'   Now we work on the future

'   We copy the page under a new name

pageselect model
pagecopy(page=forecast)

'     We extend the period to 2060

pagestruct(end=2060) * 

'     We define long-term growth rates 
'     Actually they will be applied to Dlogs (the same to the first order)
'     as we shall see later


scalar txq=0.05
scalar txn=0.01
scalar txp=0.06

'========================================
'       Changing elements in estimated equations
'========================================

'      We will show how to modify equations
'      taking the example of capacity 

'    We create a vector of parameters
'    equiVent to the vector of coefficients
'    but with "p" instead of "c"

'vector(10) p_cap

'     We transfer the estimated values except the constant

'p_cap(1)=c_cap(1) 
'p_cap(4)=c_cap(4) 

'      We reproduce the equation
'       with the original name
'       but some coefficients are replaced by vector elements
'       (not the constant)

'      We estimate the equation and compute the residual

'       As written, the simulated equation will work in the same way as before
'       but now we can fix the value of any set of coefficients
'       by replacing "c" by "p" and giving a value as above
'       the remaining coefficients will be estimated

'       This can apply to one or several coefficients
'        but not to the constant
'        as EViews requires at least one coefficient to estimate

' *********************************************************************

'    Changing the estimated formulas


'---  estimating capacity -----------------------------------------------

smpl 1996 2012
genr cap=q
coef(10) c_cap
vector(10) p_cap 
p_cap(1)=c_cap(1)
p_cap(4)=c_cap(4)   
equation _eq_cap.ls(p) log(cap)=(1-p_cap(1))*log(k(-1))+p_cap(1)*log(lf)+c_cap(3)+p_cap(4)*(t-2012)*(t<=2012)+p_cap(1)*log((1+txq)/(1+txn))*(t-2012)*(t>=2012)

genr log(ur)=resid
genr cap=q/ur

'---  estimating employment -----------------------------------------------

'    We do not allow changing the formulation of the productivity trend.
 
coef(10) c_lf
vector(10) p_lf
smpl @first 2012 
genr lf_ec=0 
p_lf(1)=c_lf(1)
p_lf(2)=c_lf(2)
equation _eq_lf.ls(p) dlog(lf)=p_lf(1)*dlog(lfd)+p_lf(2)*log(lfd(-1)/lf(-1))+c_lf(3)+lf_ec
genr lf_ec=resid

'---  estimating the change in inventories -----------------------------------------------

'     We have to reestimate the equation coefficients as there is no constant term

show err_ic
coef(10) c_ic
vector(10) p_ic
smpl 1962 2012
genr ic_ec=0
smpl 1962 2012
  
equation _eq_ic.ls(p) ic/q(-1)=c_ic(1)*c_ic(2)*@pchy(q)+(1-c_ic(1))*ic(-1)/q(-2)+ic_ec 
genr ic_ec=resid

 

'    ---- estimating the actual work force ------------------------------------------------------

show err_popac
coef(10) c_popac
vector(10) p_popac

'      Special case : we want to set the Value of a coefficient and estimate the rest

'      We create a normal vector in the same way as coefficients
'       with "p" instead of "c"

'      We just have to replace "c" by "p" in the equation
'      and give our Value to the corresponding "p" element

'      This makes it easy to switch the definition

'      Here this applies to the third coefficient
'      with the Value 0.6
 
smpl 1962 2012
genr popac_ec=0
smpl 1996 2012 
p_popac(1)=c_popac(1)
p_popac(2)=c_popac(2)
p_popac(3)=c_popac(3)
p_popac(4)=c_popac(4)
equation _eq_popac.ls(p) d(popac)/pop1564(-1)=c_popac(1)*d(lt)/pop1564(-1)+c_popac(2)*d(pop1564)/pop1564(-1)-c_popac(3)*(popac(-1)/pop1564(-1)-c_popac(4)*lt(-1)/pop1564(-1)-c_popac(5))+popac_ec  

'    ----------------------------------------------------------

'    estimating the GDP deflator

show err_pq
smpl 1962 2012
scalar c_cost=0.05
genr cost=(wr*lf*(1+r_scf)+c_cost*pip*k(-1))/q
genr costw=(wr*lf*(1+r_scf))/q
coef(10) c_pq
vector(10) p_pq
genr pq_ec=0
smpl 1962 2012 
p_pq(1)=0.75
p_pq(2)=0.30
p_pq(3)=0.20
equation _eq_pq.ls(p) dlog(pq)=c_pq(1)*dlog(costw)+p_pq(2)*dlog(ur)-p_pq(3)*(log(pq(-1)/costw(-1))-p_pq(2)*log(ur(-1)))+c_pq(5)+pq_ec
genr pq_ec=resid 

'    ----- estimating the wage rate -----------------------------------------------------
 

show err_wr 
coef(10) c_wr
vector(10) p_wr 
 
smpl 1962 2012
genr wr_ec=0 
smpl 1962 2012 

p_wr(1)=c_wr(1)
p_wr(2)=-0.15
p_wr(3)=0.20
p_wr(4)=0.50 
equation _eq_wr.ls(p) dlog(wr)=p_wr(1)*dlog(pcoh)+p_wr(2)*log(unr)-p_wr(3)*(log(costw(-1))-p_wr(4)*log(pcoh(-1))-(1-p_wr(4))*log(pq(-1)))+c_wr(5)+wr_ec 
genr wr_ec=resid 

'    ----------------------------------------------------------


'    estimating the import price

coef(10) c_pm
vector(10) p_pm
smpl 1962 2012
genr pm_ec=0
smpl @all 

p_pm(1)=0.2
p_pm(2)=0.8
p_pm(3)=0.50
p_pm(4)=0.20
p_pm(5)=c_pm(5)
equation _eq_pm.ls(p) dlog(pm)=p_pm(1)*dlog(pp)+p_pm(2)*dlog(ppx*er)-p_pm(3)*(log(pm(-1))-p_pm(4)*log(pp(-1))-(1-p_pm(4))*log(ppx(-1)*er(-1)))+p_pm(5)*(t-2012)*(t<=2012)+c_pm(6) +pm_ec
 
genr pm_ec=resid 

'    ----------------------------------------------------------


'    estimating the export price


show err_px
coef(10) c_px
vector(10) p_px
smpl @all
genr px_ec=0 

p_px(1)=0.60
p_px(2)=0.40
p_px(3)=0.50
p_px(4)=0.80
p_px(5)=c_px(5)
equation _eq_px.ls(p) dlog(px)=p_px(1)*dlog(pp)+p_px(2)*dlog(ppx*er)-p_px(3)*(log(px(-1))-p_px(4)*log(pp(-1))-(1-p_px(4))*log(ppx(-1)*er(-1)))+p_px(5)*(t-2012)*(t<=2012)+c_px(6)+px_ec
genr px_ec=resid 

'    ----------------------------------------------------------

'    estimating household consumption

show err_coh
coef(10) c_coh
vector(10) p_coh
smpl 1962 2012
genr coh_ec=0
smpl 1996 2012
 
p_coh(2)=c_coh(2)
p_coh(3)=c_coh(3)
p_coh(4)=c_coh(4)
p_coh(5)=c_coh(5)
p_coh(6)=c_coh(6)
p_coh(7)=c_coh(7)


equation _eq_coh.ls(p) dlog(coh)=c_coh(1)+p_coh(2)*(t-2012)*(t<=2012)+p_coh(3)*dlog(hrdi)+p_coh(4)*log(coh(-1)/hrdi(-1))+p_coh(5)*d(unr)+p_coh(6)*(irs-100*@pch(pcoh))+coh_ec
genr coh_ec=resid 
smpl 2010 2100
genr coh_ec=coh_ec(-1)


'    ----------------------------------------------------------

'    estimating imports

show err_m
coef(10) c_m
vector(10) p_m
smpl 1962 2012
genr m_ec=0
smpl 1962 2012 

p_m(1)=1.5
p_m(2)=c_m(2)
p_m(3)=1
p_m(5)=c_m(5)
p_m(6)=c_m(6)
equation _eq_m.ls(p) dlog(m)=p_m(1)*dlog(td)+p_m(2)*log(compm)+p_m(3)*log(ur)+c_m(4)+p_m(5)*log(m(-1)/td(-1))+p_m(6)*(t-2012)*(t<=2012)+m_ec
genr m_ec=resid 

'    with UR in W and PEX 0.5


'    ----------------------------------------------------------

'    estimating exports

show err_x
coef(10) c_x
vector(10) p_x
smpl 1962 2012
genr x_ec=0
smpl 1962 2012 

p_x(1)=c_x(1)
p_x(2)=c_x(2)
p_x(3)=-0.3
p_x(4)=c_x(4) 
p_x(6)=c_x(6)
equation _eq_x.ls(p) dlog(x)=p_x(1)*dlog(wd)+p_x(2)*log(x(-1)/wd(-1))+p_x(3)*log(ur)+p_x(4)*log(compx)+c_x(5)+p_x(6)*(t-2012)*(t<=2012)+x_ec
genr x_ec=resid 

'      We recompile the model to take into account the changes

_mod_afs.update

'==========================================================
'     Setting the assumptions for the exogenous
'==========================================================

	'   Constant Values : Growth rate=0

smpl @all 

smpl 2013 2060
for %1 COH_EC ERX FDXR  K_EC CI_EC IR_ER IRL_ER IRMX IRSR IRST IRSX IRX LF_EC  M_EC NIF_ER NIG_ER PK PM_EC POPAC_EC PQ_EC PX_EC R_EXPG R_ICT R_IFP R_OIT R_PCOH R_PCOG R_PI R_PIG R_REVG R_REVQ R_SCF R_SCG R_SCW R_SUBS R_TAR R_TARX R_VAT RDEP TC URD  WR_EC X_EC IRM_ER NIXD_EC NIXX_EC R_IH R_LW R_PIP IC_EC IP_EC fcapf_er prof_er res_fdv
genr {%1}={%1}(-1)
next

	'  Variables at constant prices : Growth rate=txq

for %1  COG   IG   WD R_REVX  
genr {%1}={%1}(-1)*(1+txq)
next

	'  Populations : Growth rate=txn

for %1 LG POP1564 POP
genr {%1}={%1}(-1)*(1+txn)
next

	'  Prices : Growth rate=txp

for %1  PPX 
genr {%1}={%1}(-1)*(1+txp)
next

	'  Values : Growth rate=txp+txq

for %1  REMX 
genr {%1}={%1}(-1)*(1+txp)*(1+txq)
next

'            Purchasing power per head : Growth rate=txp-txn

for %1   SOCBR
genr {%1}={%1}(-1)*(1+txq)/(1+txn)
next

'            The time trend

genr t=t(-1)+1

'             Now we give Values to the endogenous
'             There are two main reasons

'             1 - This gives an alternate starting point for the solution algorithms
'              Sometimes this starting point is more efficient
'              One can just check

'             2 - This allows to make a residual check on the future
'              which is useful to check that :
'              using the exogenous assumptions 
'              applying the formula provides a steady state path
'              with the same growth rate as the variable it computes

'              When the condition is met for all equations
'              a steady state path exists
'              and will be reached provided the process is converging

'              A difference can come from :
'              - wrong dimensions in the assumptions
'              - non homogenous formulas
'              - wrong initialization of endogenous (not a real problem)

smpl 2013 2060
 
'        Constant Values : Growth rate=0

for %1   COMPM COMPX ER  FCAPGP IR IRL IRM IRS RCVAL RCVOL RES_WR  RMARG RPROB RPROF TTRAD UNR  UR
genr {%1}={%1}(-1)
next

'       Variables at constant prices : Growth rate=txq

for %1  CAP COH  FD HRDI I IP IH CI K  M  Q  X GDPM IC TD FDL
genr {%1}={%1}(-1)*(1+txq)
next

'       Populations : Growth rate=txn

for %1 LFD  LF LW LS LT   POPAC UN  popt
genr {%1}={%1}(-1)*(1+txn)
next

'      Deflators : Growth rate = txp

for %1    COST PCOG PCOH PFD PFDXT PPI PIG PM PMT  PP PQ PX UWC PGDPM PIP COSTW pfd1 pfd2 pfdl
genr {%1}={%1}(-1)*(1+txp) 
next

'       Variables at current prices : Growth rate = txp+txq

for %1 COGV  EXPG FCAPF FCAPG FCAPX FDGV HDI HI ICT IFP IGV MARG MV NIF NIG NIX NIXL NIXX OIT PROF GDPMV QV  REVG REVQ REVX  SCF SCG SCW SOCB SUBS TAR TRB  VAT XV  NIXD WAGE WAGEF WAGEG REM FDV FDLV
genr {%1}={%1}(-1)*(1+txp)*(1+txq)
next

'       Variables at current prices  per head : Growth rate=txp+txq-txn

for %1 WR  
genr {%1}={%1}(-1)*(1+txp)*(1+txq)/(1+txn)
next

'      Variables at constant prices  per head : Growth rate=txp+txq-txn

for %1 LP LPT RELC
genr {%1}={%1}(-1)*(1+txq)/(1+txn)
next 

'==========================================================
'     Solving the model on the future (basic simulation)

'==========================================================

'      Now we solve the model on the future
'      until 2060
'      using the basic assumptions

'       The scenario is "scenario 1"
'       The suffix is "_b"
'       The convergence criterion is 10-6 
'                   (relative difference from an iteration to the next)
'        The maximum number of iterations is 1001
'                    giving a special number can help to associate a failure message
'                    to a specific solve statement'               
'        The exclude statement states that all endogenous will be computed
'                    it cancels any previous exclusions
'                    which may remain from previous simulations of "Scenario 1"


smpl 2013 2060 
scalar p_for=1
for !i=1 to 3
scalar p_forc={!i} 

'---  estimating investment -----------------------------------------------

smpl 2013 2060
genr q=q(-1)*(1+txq)
smpl 1980 2012  
coef(10) c_ip
vector(10) p_ip 
genr ip_ec=0
p_ip(1)=0.6  ' c_ip(1)
p_ip(2)=0.2 ' c_ip(2)
p_ip(3)=0.1 ' c_ip(3) 

equation _eq_ip.ls(p) ip/k(-1)=p_ip(1)*ip(-1)/k(-2)+(p_for=1)*(p_ip(2)*(q-q(-1))/q(-1)+p_ip(3)*log(ur))+(p_for=2)*(p_ip(2)*(q(1)-q)/q+p_ip(3)*log(ur))+(p_for=3)*(p_ip(2)*0.125*(q(8)-q)/q+p_ip(3)*log(ur))+c_ip(4)+ip_ec 
genr ip_ec=resid
'    ----------------------------------------------------------

'    estimating household consumption

show err_coh
coef(10) c_coh
vector(10) p_coh
smpl 1962 2012
genr coh_ec=0
smpl 1996 2012
 
p_coh(2)=c_coh(2)
p_coh(3)=c_coh(3)
p_coh(4)=c_coh(4)
p_coh(5)=c_coh(5)
p_coh(6)=c_coh(6)
p_coh(7)=c_coh(7)


equation _eq_coh.ls(p) dlog(coh)=c_coh(1)+p_coh(2)*(t-2012)*(t<=2012)+(p_forc=1)*(p_coh(3)*dlog(hrdi)+p_coh(4)*log(coh(-1)/hrdi(-1))+p_coh(5)*d(unr))+(p_forc=2)*(p_coh(3)*dlog(hrdi(1))+p_coh(4)*log(coh(-1)/hrdi)+p_coh(5)*d(unr))+(p_forc=3)*(p_coh(3)*0.25*dlog(hrdi(4))+p_coh(4)*log(coh(-1)/hrdi(3))+p_coh(5)*d(unr))+p_coh(6)*(irs-100*@pch(pcoh))+coh_ec
genr coh_ec=resid 
smpl 2010 2100
genr coh_ec=coh_ec(-1)

smpl 2013 2060
genr ip_ec=ip_ec(-1)
_mod_afs.update  
_mod_afs.solveopt(n=t,m=5000,c=1e-6,o=g,d=d )
_mod_afs.scenario "scenario 1"
_mod_afs.append assign @all _b{!i}
_mod_afs.exclude {%exclude}
_mod_afs.override   
smpl 2013 2060 
solve(n=t,m=5000,c=1e-6,o=g,d=d ) _mod_afs  

'==========================================================
'     Solving the model on the future (shocked assumptions)
'==========================================================

'     Now we shall produce a set shocks (in the preafst case 7)

smpl 2000 2060

'    The group called shocks_v will contain the list of 7 shocked variables

group shocks_v  ig erx r_vat r_tar r_tarx wd m_ec

'    The group called shocks_l will contain 7 letters associated to each shock
'     but the letters must be known as series 
'     as groups can contain only series

'     We create artificial series 
'      but only for the non-existing ones of course (not t or x or m.......)

for %1 ex vt tl tx wd im gd
if @isobject(%1)=0 then
genr {%1}=na
endif
next

'      We create the group

delete(noerr) shocks_l
group shocks_l  gd ex vt tl tx wd im 

'    Now we compute the additional change for each assumption, 
'    using the name of the variable
'    The shock will only start in 2006
'    to check that the difference comes only from the shock

'      1 - Shock g : +1 GDP point on Government demand

genr ig_gd{!i}=ig+.01*gdpm_b{!i}*(t>=2020)*(t<=2030)

'      2 - Shock r : 1% devaluation of the Euro

genr erx_ex{!i}=erx*(1+.01*(t>=2020)*(t<=2030))

'      3 - Shock t : -1 point on the VAT rate

genr r_vat_vt{!i}=r_vat-.01*(t>=2020)*(t<=2030)

'      4 - Shock f : -1 point on the local tariffs rate

genr r_tar_tl{!i}=r_tar-.01*(t>=2020)*(t<=2030)

'      5 - Shock y : -1 point on the foreign tariffs rate

genr r_tarx_tx{!i}=r_tarx-.01*(t>=2020)*(t<=2030)

'      6 - Shock w : +1% on World demand addressed to France

genr wd_wd{!i}=wd*(1+.01*(t>=2020)*(t<=2030))

'      7 - Shock n : +1% on ex-ante imports

genr m_ec_im{!i}=m_ec+.01*(t>=2020)*(t<=2030)

'     The loop on the shocks

for !j=1 to  shocks_v.@count

smpl 2013 2060

'   We get the name of the shocked variable and the associated letter

%2=shocks_v.@seriesname(!j) 
%3=shocks_l.@seriesname(!j)

'    We set the solution suffix using the letter 
'    We control no endogenous is excluded from the simulation
'    We override the variable associated to the current shock
'    We solve the model

smpl 2013 2060

'    We solve the model

_mod_afs.scenario "scenario 1"
_mod_afs.append assign @all _{%3}{!i}
_mod_afs.exclude   {%exclude}
_mod_afs.override {%2}
solve(n=t,m=5000+!j,c=1e-6,o=g,d=d,t=g) _mod_afs

'   We compute the difference to the base simulation, in absolute and relative terms

for !k=1 to _g_vendog.@count
%st1=_g_vendog.@seriesname(!k)
series d{%3}{!i}_{%st1}={%st1}_{%3}{!i}-{%st1}_b{!i}
series p{%3}{!i}_{%st1}=100* d{%3}{!i}_{%st1}/({%st1}_b{!i}+ ({%st1}_b{!i}=0))
series dv{!i}_{%st1}=d{%3}{!i}_{%st1}
series pv{!i}_{%st1}=p{%3}{!i}_{%st1}
next

'   We create groups for variations for a specific list of important variables

group g_v{%3}{!i} P{%3}{!i}_PFD P{%3}{!i}_PM P{%3}{!i}_PX P{%3}{!i}_PQ P{%3}{!i}_WR P{%3}{!i}_FD P{%3}{!i}_gdpm P{%3}{!i}_X P{%3}{!i}_M P{%3}{!i}_I P{%3}{!i}_COH P{%3}{!i}_UR P{%3}{!i}_CAP  P{%3}{!i}_LF P{%3}{!i}_K P{%3}{!i}_UNR  D{%3}{!i}_FCAPGP P{%3}{!i}_RCVAL P{%3}{!i}_RCVOL P{%3}{!i}_TTRAD 

'   Or very important ones

group g_w{%3}{!i} P{%3}{!i}_FD P{%3}{!i}_gdpm P{%3}{!i}_X P{%3}{!i}_M   P{%3}{!i}_PQ  

'    We create a group for variations for all variables

group g_v2{!i} pV{!i}_* dV{!i}_* 

'      We store all shocks in Excel files (2025 and 2060)
'      using the letter associated to the shock

smpl 2019 2025
write(t=xls) v2_{%3}{!i}.xls g_v2{!i} 
smpl 2016 2050
write(t=xls) w2_{%3}{!i}.xls g_v2{!i} 

output(r) graph_1

alpha title_gd="Government demand"
alpha title_ex="the exchange rate"
alpha title_vt="the Value added tax" 
alpha title_tl="shock on local tariffs"
alpha title_tx="shock on foreign tariffs"
alpha title_wd="shock on foreign quotas"
alpha title_im="shock on local quotas"  

alpha units_gd="+1 point of GDP"
alpha units_ex="+1 point of the rate"
alpha units_vt="-1 point of the rate"
alpha units_tl="-1 point of the rate"
alpha units_tx="+1% of ex ante world demand"
alpha units_wd="-1 point of the rate"
alpha units_im="+1% of ex ante imports "

%title=@elem(title_{%3},"2020")
%units=@elem(units_{%3},"2020")

smpl 2013 2050

'    Supply - demand graph
 
graph _gr_{%3}{!i}1.line P{%3}{!i}_fd P{%3}{!i}_gdpm P{%3}{!i}_x P{%3}{!i}_m P{%3}{!i}_pq   
_gr_{%3}{!i}1.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(Final demand)
_gr_{%3}{!i}1.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(GDP)
_gr_{%3}{!i}1.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(Exports)
_gr_{%3}{!i}1.setelem(4) symbol(4) lcolor(orange) lwidth(0.25) lpat(4) legend(Imports)
_gr_{%3}{!i}1.setelem(5) symbol(10) lcolor(purple) lwidth(0.25) lpat(5) legend(GDP deflator) 
_gr_{%3}{!i}1.legend position(botleft)
_gr_{%3}{!i}1.axis(left) grid
_gr_{%3}{!i}1.axis(bottom) grid 
_gr_{%3}{!i}1.addtext(t,font=12,x) {%title} : The supply - demand equilibrium \r Case {!i}  
_gr_{%3}{!i}1.addtext(l,font=11) in percentage 
_gr_{%3}{!i}1.addtext(r,font=10) shock : {%units}

print(l) _gr_{%3}{!i}1

close _gr_{%3}{!i}1 

'    Production

graph _gr_{%3}{!i}2.line P{%3}{!i}_q p{%3}{!i}_cap p{%3}{!i}_k p{%3}{!i}_lf p{%3}{!i}_q-p{%3}{!i}_cap
_gr_{%3}{!i}2.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(Value added)
_gr_{%3}{!i}2.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(Capacity)
_gr_{%3}{!i}2.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(Capital)
_gr_{%3}{!i}2.setelem(4) symbol(4) lcolor(orange) lwidth(0.25) lpat(4) legend(Employment)
_gr_{%3}{!i}2.setelem(5) symbol(10) lcolor(purple) lwidth(0.25) lpat(5) legend(Rate of use) 
_gr_{%3}{!i}2.legend position(botleft)
_gr_{%3}{!i}2.axis(left) grid
_gr_{%3}{!i}2.axis(bottom) grid 
_gr_{%3}{!i}2.addtext(t,font=12,x)  {%title} : The production elements \r Case {!i}  
_gr_{%3}{!i}2.addtext(l,font=11) in percentage
_gr_{%3}{!i}2.addtext(r,font=10) shock : {%units} 

print(l) _gr_{%3}{!i}2

close _gr_{%3}2


'    Ratios

graph _gr_{%3}{!i}3.line  p{%3}{!i}_relc p{%3}{!i}_k-p{%3}{!i}_lf   p{%3}{!i}_ur d{%3}{!i}_unr
_gr_{%3}{!i}3.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(Relative cost)
_gr_{%3}{!i}3.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(Capital-Labour ratio)
_gr_{%3}{!i}3.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(Rate of use)
_gr_{%3}{!i}3.setelem(4) symbol(4) lcolor(orange) lwidth(0.25) lpat(4) legend(Unemployment rate in points) 
_gr_{%3}{!i}3.legend position(botleft)
_gr_{%3}{!i}3.axis(left) grid
_gr_{%3}{!i}3.axis(bottom) grid 
_gr_{%3}{!i}3.addtext(t,font=12,x)  {%title} : The ratios 
_gr_{%3}{!i}3.addtext(l,font=11) in percentage
_gr_{%3}{!i}3.addtext(r,font=10) shock : {%units}  

print(l) _gr_{%3}{!i}1

close _gr_{%3}{!i}1

'    External trade 1

graph _gr_{%3}{!i}4.line p{%3}{!i}_xV p{%3}{!i}_mV p{%3}{!i}_rcVAL
_gr_{%3}{!i}4.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(Exports)
_gr_{%3}{!i}4.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(Imports)
_gr_{%3}{!i}4.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(Exports-Imports ratio) 
_gr_{%3}{!i}4.legend position(botleft)
_gr_{%3}{!i}4.axis(left) grid
_gr_{%3}{!i}4.axis(bottom) grid 
_gr_{%3}{!i}4.addtext(t,font=12,x)  {%title} : External trade at current prices  
_gr_{%3}{!i}4.addtext(l,font=11) in percentage
_gr_{%3}{!i}4.addtext(r,font=10) shock : {%units}  

' print(l) _gr_{%3}{!i}4

close _gr_{%3}{!i}4


'    External trade 2

graph _gr_{%3}{!i}5.line p{%3}{!i}_rcvol p{%3}{!i}_ttrad p{%3}{!i}_rcVAL
_gr_{%3}{!i}5.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(At constant prices)
_gr_{%3}{!i}5.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(Terms of trade)
_gr_{%3}{!i}5.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(At constant prices) 
_gr_{%3}{!i}5.legend position(botleft)
_gr_{%3}{!i}5.axis(left) grid
_gr_{%3}{!i}5.axis(bottom) grid 
_gr_{%3}{!i}5.addtext(t,font=12,x)  {%title} : The exports - import ratios 
_gr_{%3}{!i}5.addtext(l,font=11) in percentage
_gr_{%3}{!i}5.addtext(r,font=10) shock : {%units}  

print(l) _gr_{%3}{!i}5

close _gr_{%3}{!i}5

'    Prices

graph _gr_{%3}{!i}6.line p{%3}{!i}_wr p{%3}{!i}_pfd p{%3}{!i}_pq p{%3}{!i}_px p{%3}{!i}_pm
_gr_{%3}{!i}6.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(Wage rate)
_gr_{%3}{!i}6.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(Consumption)
_gr_{%3}{!i}6.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(Value added)
_gr_{%3}{!i}6.setelem(4) symbol(4) lcolor(orange) lwidth(0.25) lpat(4) legend(Exports)
_gr_{%3}{!i}6.setelem(5) symbol(10) lcolor(purple) lwidth(0.25) lpat(5) legend(Imports) 
_gr_{%3}{!i}6.legend position(botleft)
_gr_{%3}{!i}6.axis(left) grid
_gr_{%3}{!i}6.axis(bottom) grid 
_gr_{%3}{!i}6.addtext(t,font=12,x)  {%title} : The prices   
_gr_{%3}{!i}6.addtext(l,font=11) in percentage 
_gr_{%3}{!i}6.addtext(r,font=10) shock : {%units} 


graph _gr{%3}{!i}tot.merge _gr_{%3}{!i}1 _gr_{%3}{!i}2 _gr_{%3}{!i}3 _gr_{%3}{!i}4 _gr_{%3}{!i}5 _gr_{%3}{!i}6  
_gr{%3}{!i}tot.align(3,2,2)

' print(l) _gr_{%3}{!i}6

close _gr_{%3}{!i}6

group g_t{%3} p{%3}{!i}_GDPM p{%3}{!i}_FD p{%3}{!i}_ip p{%3}{!i}_i p{%3}{!i}_coh p{%3}{!i}_M p{%3}{!i}_X p{%3}{!i}_RCVOL p{%3}{!i}_CAP p{%3}{!i}_UR  p{%3}{!i}_PGDPM p{%3}{!i}_PX p{%3}{!i}_PM p{%3}{!i}_PCOH p{%3}{!i}_WR p{%3}{!i}_COMPX p{%3}{!i}_COMPM p{%3}{!i}_Lf p{%3}{!i}_LT d{%3}{!i}_UNR  100*d{%3}{!i}_RMARG 100*d{%3}{!i}_RPROB
smpl 2013 2025
 
%tab="_TAB"+%3+@str({!i})
if @isobject(%tab) then
delete %tab
endif

smpl 2013 2028
'   show(t) g_t{%3}
freeze({%tab}) g_t{%3}
{%tab}.deleterow(2)
{%tab}.insertrow(2)
{%tab}.insertrow(13)
{%tab}.insertrow(21)
{%tab}.insertrow(25)
{%tab}.insertrow(27)
{%tab}.setjust(A1:A30)left
{%tab}.setjust(A1:Q1) center
{%tab}.setwidth(A) 25
{%tab}.setwidth(B:Q) 6.5
{%tab}.setformat(B2:Q30) f.2
{%tab}.setlines(A1:Q30) +o
{%tab}.setlines(A1:Q1) +b
{%tab}.setlines(A12:Q12) +b
{%tab}.setlines(A20:Q20) +b
{%tab}.setlines(A24:Q24) +b
{%tab}.setlines(A30:Q30) +b 
{%tab}.setlines(A1:A30) +r
{%tab}.setfont(A2) +b
{%tab}.setfont(A13) +b
{%tab}.setfont(A21) +b
{%tab}.setfont(A25) +b 

{%tab}(1,1)=""

{%tab}(2,1)="Real equlibrium"
{%tab}(3,1)="GDP"
{%tab}(4,1)="Final demand"
{%tab}(5,1)="Productive Investment"
{%tab}(6,1)="Total Investment"
{%tab}(7,1)="Household Consumption"
{%tab}(8,1)="Imports"
{%tab}(9,1)="Exports"
{%tab}(10,1)="Export-import ratio"
{%tab}(11,1)="Productive capacity"
{%tab}(12,1)="Rate of use (*)"
{%tab}(13,1)="Deflators"
{%tab}(14,1)="GDP  "
{%tab}(15,1)="Exports  "
{%tab}(16,1)="Imports  "
{%tab}(17,1)="Consumer price index"
{%tab}(18,1)="Wage rate"
{%tab}(19,1)="Export competitiveness"
{%tab}(20,1)="Import competitiveness"
{%tab}(21,1)="Employment"
{%tab}(22,1)="Firms employment"
{%tab}(23,1)="Total employment"
{%tab}(24,1)="Unemployment rate (*)"
{%tab}(25,1)="Balances"
{%tab}(26,1)="Margins rate (*)"
{%tab}(27,1)="Profits rate (*)" 
{%tab}(28,1)="Government expenditures (*)"
{%tab}(29,1)="Government revenue (*)" 
{%tab}(30,1)="Government balance  (*)" 
{%tab}.setindent(A) 4

close g_t{%3}{!i}
show err_{!i}{!j}
next
next

'       We save the workfile

smpl 2013 2060
save projfor21_afs


