

subroutine star

tic   

  
group g_vendo1 {%l_endo}      
group g_vexog1 {%l_exo}         

'    We copy the user model into _model

 copy %model _model           '  The model name 

'      We delete Scenario 1 (it exists)

_model.scenario(d) "Scenario 1"

'      We set the sample at the full range 

smpl @first @last
genr _dum2=1

smpl _range

'    We create a dummy variable for the full range
'    anc compute the number of observations      

if @isobject("_dum") then 
delete _dum
endif

genr _dum=1 

scalar _obsnb=@obssmpl

for !i=1 to g_vexog1.@count
vector(_obsnb) delv_{!i}  
next
 

'      nstar is the common number

scalar nstar=g_vexog1.@count 

'      The loop will run on all observations in the range

'      The condition identifies the !iper th period in the sample
'      for which a lag of !iper will produce an NA
'      but not a lag of !iper+1 

for !iper=1 to _obsnb 
smpl _range if _dum(-!iper)=na and _dum(-!iper+1)<>na

'      We build Scenario 0 as the base
'      It will contain the current solution
'      The associated suffix will be "_0"
'      We declare all the overriden exogenous
'      (with the currently best solution)

'      (note : we start with a blank list and fill it one by one)

_model.scenario(n) "Scenario 0"

_model.append assign @all _0 
_model.exclude {%exclude}

_model.solveopt(d=d,n=t,o=b,i=p,s=d) 
_model.solve(d=d,n=t,o=b,i=p,s=d) 
_model.override  
for !i=1 to g_vexog1.@count
%1=g_vexog1.@seriesname(!i)
_model.override(m) {%1}
next

'     Now we create the alternate scenarios 
'     for computation of the Jacobian
'     They are numbered 1 to nstar (here 2)
'     The suffix is "_n"
'     The exogenous are the same as Scenario 0

'     Note : all exogenous have to be overriden
'     but only one will change from the _0 value
'     for a given scenario

for !i=1 to nstar
_model.scenario(n,a={!i},i="Scenario 0") Scenario {!i}
_model.append assign @all _sce{!i}
_model.exclude {%exclude}
next

'     Now we define the Jacobian

matrix(nstar,nstar) jacob 


'   '   '   print jacob

'     Now we initialize the exogenous instruments
'     used to reach the target

for !i=1 to g_vexog1.@count
%1=g_vexog1.@seriesname(!i)
genr {%1}_cur={%1}
genr {%1}_0={%1}
for !j=1 to g_vexog1.@count
genr {%1}_sce{!j}={%1}
next
next

'      And the endoenous target variables

for !i=1 to g_vendo1.@count
%1=g_vendo1.@seriesname(!i)
'genr {%1}_0={%1}
genr {%1}_cur={%1}_0
next

'     We set the maximum number of iterations
'     and the convergence criterion

scalar nitmax=20
scalar sconv=1e-6

'     We initialize as control variables
'      the number of iterations 
'      And the variable controlling the convergence

!niter=0
!iconv=0

'     We double the elements so they can be displayed

scalar niter=0
scalar iconv=0

'    We display several elements for control
     
'   '   print g_vexog1 g_vendo1
'   '   print *_cur *_star

'---------------------------------------------------------
'      Now we start the loop
'---------------------------------------------------------

'     It will run while convergence is not achieved 
'     and the maximum numbre of loops is not reached 

while !niter<=nitmax and !iconv=0 

'     We increment the iteration counter

!niter=!niter+1
scalar niter=niter+1

'       We test for convergence
'       We suppose it is achieved (!iconv=1)
'       Then we look at the relative difference 
'        between the present solution and the target
'        for each targetted endoenous

'        If the relative difference is higher than the criterion
'        for any target
'        convergence is not yet reached (!iconv=0)

!iconv=1
scalar iconv=1

for !j=1 to g_vendo1.@count
%1=g_vendo1.@seriesname(!j)

genr dele_{!j}=({%1}_star-{%1}_cur)/({%1}_cur+({%1}_cur=0))
stom(dele_{!j},delv_{!j},_range)  
if @abs(delv_{!j}({!iper}))>sconv then
!iconv=0
scalar iconv=0
endif
next  


'      We display the differences

'   '   print dele_*

'       We compute the base solution
'        defined as Scenario 0

_model.scenario "Scenario 0"
_model.exclude {%exclude}
solve(o=b,i=p) _model

'       The solution values are set as current

for !i=1 to g_vendo1.@count
%1=g_vendo1.@seriesname(!i)
genr {%1}_cur={%1}_0
if niter=1 then
genr {%1}_base={%1}_0
endif
next

'        We save the initial solution (for comparison with the shocked one later)

if niter=1 then
for !i=1 to g_vendo.@count
%1=g_vendo.@seriesname(!i)
genr {%1}_base={%1}_0
next
endif

'      We display the current solution (exogenous + endoenous) and the targets

show iter={!niter} 
print *_cur  *_star

'      Now we compute the Jacobian
'      We start a loop on the shocked instruments

for !i=1 to g_vexog1.@count

'       For each exogenous, we compute the whole set of overriding instruments
'       shocking only the current one by 0.01 %
'       while the others keep their base value
'       This is necessary to implement the current changes

for !j=1 to g_vexog1.@count
%2=g_vexog1.@seriesname(!j)
genr {%2}_sce{!i}={%2}_cur*(1+.001*({!i}={!j}))
next

'       We solve the model under Scenario !i

_model.scenario Scenario {!i}
_model.exclude {%exclude}
_model.solve(o=b,i=p)

'       Now we compute the relative change in the target endoenous
'       This will give a column of the Jacobian matrix

for !j=1 to g_vendo1.@count
%2=g_vendo1.@seriesname(!j)
genr _z=({%2}_sce{!i}-{%2}_cur)/({%2}_cur+({%2}_cur=0))/0.001
stom(_z,_zscal,_range)
jacob(!j,!i)=_zscal({!iper})
next

next

'      This ends the computation of the Jacobian
 
'       We compute its inverse

'   '   print jacob

matrix jacob_inv=@inverse(jacob)

'   '   print jacob_inv

'       We apply to each exogenous a change equal to
'       the inverse of the jacobian
'       times the remaining error.

'       This gives a new solution for the exogenous
'        We start the process again until convergence (hopefully)

for !i=1 to g_vexog1.@count
%1=g_vexog1.@seriesname(!i)
genr {%1}_old={%1}_cur
for !j=1 to g_vendo1.@count
%2=g_vendo1.@seriesname(!j)
genr {%1}_cur={%1}_cur+{%1}_old*jacob_inv(!i,!j)*({%2}_star-{%2}_cur)/({%2}_cur+({%2}_cur=0))
next
genr {%1}_sce{!i}={%1}_cur
genr {%1}_0={%1}_cur
genr delxc_{%1}=({%1}_cur-{%1}_old)/{%1}_old
genr delxt_{%1}=({%1}_cur-{%1})/{%1}
next
'   print delxc_*
'   print delxt_*
wend

for !i=1 to g_vendo.@count
%1=g_vendo.@seriesname(!i)
genr delf_{%1}=100*({%1}_0-{%1}_base)/({%1}_base+({%1}_base=0))
next

'    we set the endoenous to the solution values

for !i=1 to g_vendo.@count
%1=g_vendo.@seriesname(!i)
genr {%1}={%1}_0
next

for !i=0 to g_vendo1.@count
_model.scenario(d) Scenario !i
next

next   '  end of the loop on periods

'     We restore the full sample

smpl _range

toc  

endsub


