
'       An example of data transfer

'      This program will start from the data for Senegal
'       provided by Othe World Bankb

'      We decide on the directory
'      This is not generally necessary
'       except if one works on several projects
'      or maintains several directories for the same project
'       It guarantees trial versions do not destroy official ones

cd "c:\users\jean louis brillet\documents\eviews\book_africa\senegal"

'     The original data is contained in a page called "wb" with the original names
'     The page "model" contains links to the "wb" series
'      with the addition of a "v_" prefix

'-------------------------------------------------------------------------
'     This technique can be used with any source 

'      In the best case, if the set available is the same (or larger) than the World Bank set
'      one has just to replace the World Bank names in the following statements
'-------------------------------------------------------------------------

'       we close the original file "senegal_wb"  
'      in case it is already open 
'      having two versions of the same file open in memory is quite dangerous...

close data_sen 

'     We open it again

open data_sen

'       We copy the definition of the group to a page called "model"
 
'       We delete the page if it exists

pagedelete model

'       We create the page annual from 1960 to 2020

pagecreate(page=model) a 1960 2020
delete *

'      We copy the definition of the group g_wb (not the series) from the page wb to model
'      This is done by "g=l"

copy(g=l) wb\g_wb   

'       We create linked variables adding the prefix "v_" to the original series names
'       to separate them from the variables we are going to compute

smpl 1960 2020
for !i=1 to g_wb.@count

'     We get the name

%1=g_wb.@seriesname(!i)

'     We  create the linked variable

link v_{%1}

'    We establish the link

v_{%1}.linkto wb\{%1}
next   

'     We generate a time trend

smpl 1960 1960
genr t=1960
smpl 1961 2020
genr t=t(-1)+1
pageselect model

'     We have to make an assumption on the sharing of indirect taxes 
'     into VAT and other indirect taxes
'     as OECD provides only a global variable

'     p_oit = assumption on the share of oit in indirect taxes

'     indirect taxes are not separated into VAT and other taxes
'
scalar s_p_oit=0.2

'     we create a time trend
'     with the value of the year for the first quarter
'     to which we add 1 for each following quarter of the year 

'   This will be quite useful to :

'      create yearly time trends
'      replace actual dummy variables by expressions using logical conditions
'      much easier to manage

smpl 1960 1960
genr s_t=1960
smpl 1961 2020
genr s_t=s_t(-1)+1

'     Now we start with the supply - demand equilibrium

smpl 1960 2020
genr s_usd=v_PA_NUS_FCRF
genr s_gdpv=v_ny_gdp_mktp_cn
genr s_gdp=v_ny_gdp_mktp_kn

'    CPI

genr s_cohv=v_ne_con_petc_cn
genr s_coh=v_ne_con_petc_kn
genr s_pcoh=s_cohv/s_coh

'   The model separates market GDP

genr s_cgw=0
genr s_gdpmv=s_gdpv-s_cgw
genr s_gdpm=s_GDP-s_CGw/s_pcoh
genr s_pgdpm=s_gdpmv/s_gdpm

'      Trade af current and constant prices, associated deflators

genr s_mv=v_ne_imp_gnfs_cn
genr s_m=v_ne_imp_gnfs_kn
genr s_pm=s_mv/s_m
genr s_xv=v_ne_exp_gnfs_cn
genr s_x=v_ne_exp_gnfs_kn
genr s_px=s_xv/s_x

'      Final demand, VAT and value added (excluding VAT)
'      This separation is important as VAT will apply to final demand

genr s_fd=s_GDPm+s_M-s_X
genr s_fdv=s_GDPmV+s_MV-s_XV
genr s_pfd=s_fdv/s_fd
genr s_oit=(1-s_p_oit)*v_ny_tax_nind_cn 
genr s_vat =s_p_oit*v_ny_tax_nind_cn 
genr s_r_vat =s_vat/(s_fd*s_pfd-s_vat)

'       value added (excluding VAT)

genr s_qv=s_gdpmv-s_vat
genr s_r_oit=s_oit/(s_qv-s_oit)
scalar s_r_vat0=@elem(s_r_vat,"2005")
genr s_q = s_gdpm-s_r_vat0*s_fd/(1+s_r_vat0)
genr s_pq=s_qv/s_q

'      Investment

'    *****pb : government investment

genr s_ihv=0      '    *****pb : no measure of housing investment
genr s_ih=0        '    *****pb : no measure of housing investment
genr s_ipv=v_ne_gdi_fprv_cn
genr s_igv=v_ne_gdi_ftot_cn- v_ne_gdi_fprv_cn 
genr s_ip=v_ne_gdi_ftot_kn*s_ipv/(s_ipv+s_igv+s_ihv)
genr s_ig=v_ne_gdi_ftot_kn*s_igv/(s_ipv+s_igv+s_ihv)
genr s_pip=s_ipv/s_ip
genr s_pig=s_igv/s_ig
genr s_dep=v_ny_adj_dkap_cd   ' *****rem additional measure of depreciation in USD

'    Capital and capacities

genr s_tc=1 
genr s_cap=s_q     ' *****rem : will be computed after estimation of production function
smpl 1964 2013
genr s_k=2*s_q
genr s_rdep = 0.05
smpl 1965 2013
genr s_k=s_k(-1)*(1-s_rdep)+s_ip
smpl @all
genr s_ur=s_q/s_k(-1) 
genr s_pk=s_cap/s_k(-1)
genr s_urd=1
genr s_ci=s_tc*s_q
genr s_td=s_fd+s_ci

'    Elements of demand 

'       Changes in inventories

genr s_icv=v_ne_gdi_stkb_cn
genr s_ic=v_ne_gdi_stkb_kn
genr s_pic=s_icv/s_ic

'        Government consumption (includes wages of civl servants)

genr s_cogv=v_ne_con_govt_cn
genr s_cog=v_ne_con_govt_kn
genr s_pcog=s_cogv/s_cog
genr s_r_pcog=s_pcog/s_pfd

'         Final demand of Government

genr s_fdgv=s_cogv+s_igv
genr s_fdg=s_cog+s_ig

genr s_gd=s_ig+s_cog

genr s_fdxr=0    '    *****rem : look further into the composition of demand

'    employment, unemployment, population

genr s_popt=v_sp_pop_totl
genr s_pop1564=s_popt*v_sp_pop_1564_to_zs/100
genr s_lt=v_sl_emp_totl_sp_zs*s_pop1564/100
genr s_lg=0         '  *****pb : no measure of civil servants
genr s_lf=s_lt-s_lg
genr s_pl=s_q / s_lf
genr s_un=v_sl_uem_totl_zs*v_sl_tlf_totl_in/100    '   *****rem : un known only in 2006
genr s_unr=s_UN/(s_lt+s_un)*100 
smpl @all
genr s_unr1=@elem(s_unr,"2006")
genr s_unr=s_unr1
delete s_unr1
genr s_un=s_lt*s_unr/100/(1-s_unr/100)
genr s_popac=s_lt+s_un
genr s_lp=s_q/s_lf

'    wages and further deflators

genr s_ls=v_sl_emp_self_zs*s_lt/100
smpl 1992 2000
genr s_ls=s_lt*(@elem(s_ls,"1991")/@elem(s_lt,"1991")*(2001-t)/10+@elem(s_ls,"2001")/@elem(s_lt,"2001")*(t-1991)/10)
smpl 2002 2012
genr s_ls=s_lt*@elem(s_ls,"2001")/@elem(s_lt,"2001") 
smpl @all
genr s_lw=s_lf-s_ls
genr s_r_lw=s_lw/s_lf 
genr s_pp=(s_qv+ s_pfd*s_ci*(1+s_r_vat0)/(1+s_r_vat)) / (s_q+s_ci)
genr s_comp=v_sl_tlf_totl_in
genr s_r_scf =0      ' ****** unknown social contributions
genr s_scf=0
genr s_wr=(s_comp-s_scf)/(s_lw+s_lg)*1000*12*2   ' *****rem : units, definition?
genr s_wage=s_wr*(s_lt-s_ls)
genr s_wagef=s_wr*(s_lf-s_ls)
genr s_wageg=s_wr*s_lg
genr s_uwc=s_wr*(1+s_r_scf)/s_lp
genr s_pfdxt=s_pfd*(1+s_r_vat0)/(1+s_r_vat)
genr s_tc=1     ' ******rem : assumption
genr s_pp=(s_pq+s_tc*s_pfdxt)/(1+s_tc)
genr s_ern=v_pa_nus_fcrf 
genr s_er=v_pa_nus_fcrf 
genr s_erx=s_ern/@elem(s_ern,"2005")
genr s_r_pip=s_pip/s_pfd
genr s_r_pcoh=s_pcoh/s_pfd
genr s_r_pig=s_pig/s_pfd

'    interest rates

genr s_irla=v_fr_inr_lend
genr s_irda=v_fr_inr_lend-v_fr_inr_lndp
genr s_ira=0.5*(s_irda+s_irla) 
genr s_irs=v_fr_inr_dpst    '    *****pb length of series 1977-1992
genr s_irl=v_fr_inr_dpst     '    *****pb length of series 1977-1992
genr s_ir=0.5*(s_irs+s_irl)
smpl 1970 1970
genr s_irm=s_ir
smpl 1971 2013
genr s_irm=0.2*s_ir+0.8*s_irm(-1)
genr s_irsx=s_irs
genr s_irmx=s_irm
genr s_irx=s_ir
genr s_irr=s_ir-100*@pch(s_pcoh)
genr s_irl_ec=0
genr s_irsr=s_irs-100*@pchy(s_pcoh)
genr s_irst=0 
genr s_relc=s_wr*(1+s_r_scf)/s_pip/(s_ir/100-@pchy(s_pcoh)+s_rdep)

'     households

smpl @all
genr s_rem=v_BX_TRF_PWKR_DT_GD_ZS*s_gdpv/100
smpl 2011 2012
genr s_rem=s_rem(-1)*s_gdpv/s_gdpv(-1)
smpl @all
genr s_remx=s_rem/s_er
genr s_socb=v_sh_xpd_publ_zs*s_gdpv/100    '  *****rem : goct healt expenditures
smpl 2012 2012
genr s_socb=s_socb(-1)*s_gdpmv/s_gdpmv(-1)    ' *****rem : not available in 2012
smpl @first 1994
genr s_socb=s_qv*@elem(s_socb,"1995")/@elem(s_qv,"1995") '   ****rem : retropolation
smpl @all
genr s_ict=0.5*v_gc_tax_ypkg_cn
genr s_subs=v_gc_xpn_trft_cn  '   *****rem : 1996 - 2001
genr s_tar=v_gc_tax_impt_cn   '   ***** rem 0 obs
genr s_tar=v_gc_tax_intt_cn  '   *****rem :  proxy ????
genr s_r_subs = s_subs/s_qv
genr s_r_tar=s_tar/s_mv
smpl @first 1995
genr s_r_subs=@elem(s_r_subs,"1996") 
genr s_r_tar=@elem(s_r_tar,"1996") 
smpl 2002 @last
genr s_r_subs=@elem(s_r_subs,"2001") 
genr s_r_tar=@elem(s_r_tar,"2001") 
smpl @all 
genr s_subs=s_r_subs*s_qv 
genr s_tar=s_r_tar*s_mv
genr s_marg=(s_qv*(1-s_r_oit+s_r_subs)-s_wagef*(1+s_r_scf))
genr s_pro=0.3*s_marg   '  *****pb : no measure of non wage revenue
genr s_revx=0.1*s_gdpv    '  *****pb : no measure of non wage revenue
genr s_revq=0.7*s_marg     '  *****pb : no measure of non wage revenue
genr s_hi =s_wage+s_socb+s_revx+s_revq+s_rem
genr s_r_ict=s_ict/s_hi    '    *****pb : only global tax on revenue
smpl @first 1995
genr s_r_ict=@elem(s_r_ict,"1996")
smpl 2002 @last
genr s_r_ict=@elem(s_r_ict,"2001")
smpl @all
genr s_ict=s_r_ict*s_hi
genr s_hdi=s_hi-s_ict
genr s_hrdi=s_hdi/s_pcoh
genr s_sr=1-s_coh/(s_hrdi)
genr s_r_scw=0.10        '  *****pb : no measure of contributions by employees
genr s_scw=s_r_scw*s_wage 
genr s_r_revx=s_revx/s_pfd
genr s_r_revq=s_revq/s_qv
genr s_wageg=s_wr*s_lg       '   ****rem : l_g not available 
genr s_r_ih=s_ih/s_hrdi

'    rates

genr s_r_scg=  s_r_scf
scalar s_r_oit0=@elem(s_r_oit,"2005")

'     external trade

genr s_r_tarx=0
scalar s_r_tarx0=@elem(s_r_tarx,"2005")
scalar s_r_tar0=@elem(s_r_tar,"2005")
genr s_ppx=v_NY_GDP_MKTP_CD/v_NY_GDP_MKTP_KD   '    rem***** look for this later 
genr s_wd =v_NE_IMP_GNFS_KD   '    rem***** look for this later  
genr s_rcvol=s_x/s_m
genr s_rcval=s_xv/s_mv
genr s_ttrad=s_px/s_pm
genr s_trb=s_xv-s_mv
genr s_nixs=v_dt_int_dstc_cd*s_ern
genr s_nixl=v_dt_int_dlxf_cd*s_ern  
genr s_nix=s_nixs+s_nixl
genr s_nixd=0.5*s_nix   '  *****rem : separating local and foreign currencies
genr s_nixx=0.5*s_nix   '  *****rem : separating local and foreign currencies
genr s_NIXD_ec=(s_NIXD-(s_NIXD(-1)*s_IRM/s_IRM(-1)-s_IR/100*0.5*s_TRB))/(s_xv+s_mv)
genr s_NIXX_ec=(s_NIXX-(s_NIXX(-1)*s_IRMX/s_IRMX(-1)*(s_er/s_er(-1))-s_IRX/100*0.5*s_TRB))/(s_xv+s_mv)
genr s_fcapx=s_trb-s_nix
genr s_PMT=s_PM*(1+s_r_tar)/(1+s_r_tar0)
genr s_compm=s_pmt/s_pp
genr s_COMPX=s_PX*(1+s_r_tarx)/(1+s_r_tarx0)/(s_PPX*s_ER)

'      firms account

genr s_marg=s_qv*(1+s_r_subs-s_r_oit)-s_wagef*(1+s_r_scf)
genr s_rmarg =s_marg / s_qv
genr s_rprob = s_marg/(s_pfd*s_k(-1))
smpl 1996 2001
genr s_ifp=0.5*v_gc_tax_ypkg_cn   ' ****rem : division 0.5
genr s_prof1=s_marg-s_revq-s_ifp
genr s_r_ifp=s_ifp/s_prof1   
genr s_r1_ifp=s_ifp/(s_marg-s_revq)
smpl 2002 @last '  *****rem : extrapolation
genr s_r1_ifp=@elem(s_r1_ifp,"2001")
genr s_ifp= s_r1_ifp*(s_marg-s_revq)
genr s_prof1=s_marg-s_revq-s_ifp
genr s_r_ifp=s_ifp/s_prof1   
smpl @first 1995
genr s_r1_ifp=@elem(s_r1_ifp,"1996")
genr s_ifp= s_r1_ifp*(s_marg-s_revq)
genr s_prof1=s_marg-s_revq-s_ifp
genr s_r_ifp=s_ifp/s_prof1   
smpl @all
genr s_fcapf1=s_prof1-s_pip*s_ip-s_pfd*s_ic
smpl 1991 1991
genr s_nif=-s_prof1*0.05
smpl 1992 2013
genr s_nif=s_nif(-1)*s_irm/s_irm(-1)-s_fcapf1
smpl 1960 2013
genr s_prof=s_marg-s_revq-s_ifp-s_nif
genr s_rprof=s_prof/(s_pfd*s_k(-1)) 
genr s_fcapf=s_prof-s_pip*s_ip-s_pfd*s_ic
genr s_i=s_ip+s_ih+s_ig
genr s_fdxr=(s_fd-(s_COH+s_IP+s_IH+s_IC+s_cog+s_IG))/s_q 
genr s_fcapf=s_prof-s_pip*s_i-s_pfd*s_ic 
genr s_nif_er=(s_nif-(s_NIF(-1)*s_IRM/s_IRM(-1)-s_IR/100*s_FCAPF))/s_qv
genr s_spread=0

'     budget elements

genr s_fcapg=-v_fs_ast_cgov_gd_zs*s_gdpv  '   *****rem : ????
genr s_socbr =s_socb/s_pcoh/s_popt
genr s_r_oit=s_oit/(s_qv-s_oit)
genr s_nig=v_gc_xpn_intp_cn
smpl 2002 @last
genr s_nig=s_nig(-1)*s_irm/s_irm(-1)-s_ir/100*s_fcapg
smpl @all
genr s_wg=s_wr
genr s_scg=s_wg*s_r_scf
genr s_revg=s_ict+s_oit+s_vat+s_scf+s_scg+s_tar+s_scw+s_ifp
genr s_r_revg=0
genr s_expg=s_revg-s_fcapg
genr s_dfgv=s_igv
genr s_r_expg=(s_expg-(s_fdgv+s_wg+s_scg+s_nig+s_socb+s_subs))/s_qv
genr s_recg=0
genr s_r_recg=0
genr s_fcapgp=100*s_fcapg/s_gdpmv
genr s_nig_er=(s_nig-(s_nig(-1)*s_irm/s_irm(-1)-s_ir/100*s_fcapg))/s_qv

genr s_relax_q=1
genr s_relax_pfd=1

wfsave data_sen


