
'      this program creates an example model


'      We define the directory 
'      this has to be adapted to your specifications

cd "c:\users\jean louis brillet\documents\eviews\book_africa\senegal"

'      The output (estimations, tests) will also be directed to a text file
'       Its name is _mod_sen.txt

output(t) _model_sen

'       We start from the data file data_1
'       We first save it under the name mod_sen
'       But as usual, we must avoid having other versions open at the same time
'       We send close statements as a precaution
'        
close data_sen
close model_sen
open data_sen
wfsave model_sen

'       We set the sample to maximum
'        The workfile dimension

smpl 1960 2012

'       We eliminate the f_ prefix
'       We do not need this identifier
'       As we are working with a single country

group g_s s_*
for !i=1 to g_s.@count
%1=g_s.@seriesname(!i)
%2=@mid(%1,3)
series {%2}={%1}
next

'      The forecasts will use long term growth rates
'      We shall define them now
'      But they will only apply beyond the last period
'      for which data is available
'      So they will affect neither estimations nor computations

'      txq : growth rates of quantities at constant prices (at country level)
'      txp : growth rates of populations (numbers of persons)
'      txp : growth rates of deflators

'      Actually by using the following growth rates
'      the growth rates will not take round vues
'      but the Dlog of the variables will
'      including the results of all multiplications and divisions

scalar txq=0.05
scalar txn=0.01
scalar txp=0.06

'   ==============================================

'    We start with the estimations

'   ==============================================

'---  estimating capacity -----------------------------------------------

smpl 1991 2012
genr cap=q
coef(10) c_cap
vector(10) p_cap
equation _eq_cap1.ls(p) log(cap)=(1-c_cap(1))*log(k(-1))+c_cap(1)*log(lf)+c_cap(3)+c_cap(4)*(t-2012)*(t<=2012)+c_cap(1)*log((1+txq)/(1+txn))*(t-2012)*(t>=2012)

equation _eq_cap.ls(p) log(cap)=(1-c_cap(1))*log(k(-1))+c_cap(1)*log(lf)+c_cap(3)+c_cap(4)*(t-2012)*(t<=2012)+c_cap(1)*log((1+txq)/(1+txn))*(t-2012)*(t>=2012)

genr log(ur)=resid
genr cap=q/ur

'---  estimating investment -----------------------------------------------

smpl 1996 2012  
coef(10) c_ip
vector(10) p_ip 
genr ip_ec=0
equation _eq_ip1.ls(p) ip/k(-1)=c_ip(1)*ip(-1)/k(-2)+c_ip(2)*@pch(q)+c_ip(2)*log(ur)+c_ip(4)+ip_ec

equation _eq_ip.ls(p) ip/k(-1)=c_ip(1)*ip(-1)/k(-2)+c_ip(2)*@pch(q)+c_ip(2)*log(ur)+c_ip(4)+ip_ec
genr ip_ec=resid

'---  estimating employment -----------------------------------------------

coef(10) c_lpt
vector(10) p_lpt
coef(10) c_lf
vector(10) p_lf
smpl @all
genr ec_lp=0
genr lpt=q/lf
equation _eq_lpt.ls(p) log(lpt)=c_lpt(1)+c_lpt(2)*(t-2012)*(t<=2012)+log((1+txq)/(1+txn))*(t-2012)*(t>=2012)

genr log(lpt)=c_lpt(1)+c_lpt(2)*(t-2012)*(t<=2012)+log((1+txq)/(1+txn))*(t-2012)*(t>=2012) 
genr lfd=q/lpt
genr lf_ec=0
equation _eq_lf.ls(p) dlog(lf)=c_lf(1)*dlog(lfd)+c_lf(2)*log(lfd(-1)/lf(-1))+c_lf(3)+lf_ec

p_lf(1)=0.50
p_lf(2)=0.35
equation _eq_lf.ls(p) dlog(lf)=p_lf(1)*dlog(lfd)+p_lf(2)*log(lfd(-1)/lf(-1))+c_lf(3)+lf_ec
genr lf_ec=resid

'---  estimating the change in inventories -----------------------------------------------
show err_ic
coef(10) c_ic
vector(10) p_ic
smpl 1962 2012
genr ic_ec=0
smpl 1962 2012
equation _eq_ic1.ls(p) ic/q(-1)=c_ic(1)*@pchy(q)+c_ic(2)+c_ic(3)*ic(-1)/q(-2)+ic_ec 

p_ic(1)=0.0
p_ic(3)=0.0
'quation _eq_ic.ls(p) ic/q(-1)=c_ic(1)+c_ic(2)*ic(-1)/q(-2)+(1-c_ic(2))*p_ic(3)*@pchy(q)+c_ic(2)+ic_ec
genr ic_ec=resid
 

'    ---- estimating the actual work force ------------------------------------------------------

show err_popac
coef(10) c_popac
vector(10) p_popac

'      Special case : we want to set the vue of a coefficient and estimate the rest

'      We create a normal vector in the same way as coefficients
'       with "p" instead of "c"

'      We just have to replace "c" by "p" in the equation
'      and give our vue to the corresponding "p" element

'      This makes it easy to switch the definition

'      Here this applies to the third coefficient
'      with the vue 0.6
 
smpl 1962 2012
genr popac_ec=0
smpl 1962 2012
equation _eq_popac1.ls(p) d(popac)/pop1564(-1)=c_popac(1)*d(lt)/pop1564(-1)+c_popac(2)*d(pop1564)/pop1564(-1)-c_popac(3)*(popac(-1)/pop1564(-1)-c_popac(4)*lt(-1)/pop1564(-1)-c_popac(5))+c_popac(6)*(t-2012)*(t<=2012)+popac_ec
 
p_popac(1)=0.3
p_popac(2)=0.2
p_popac(3)=0.2
p_popac(4)=0.3
p_popac(6)=0.0
equation _eq_popac.ls(p) d(popac)/pop1564(-1)=p_popac(1)*d(lt)/pop1564(-1)+p_popac(2)*d(pop1564)/pop1564(-1)-p_popac(3)*(popac(-1)/pop1564(-1)-p_popac(4)*lt(-1)/pop1564(-1)-c_popac(5))+p_popac(6)*(t-2012)*(t<=2012)+popac_ec

'    Managing the residuals is also special
'    as the equation uses an AR process

'    We start by storing the RESID variable

genr resid_popac=resid

'    Then we "forecast" the residual for the first period in the sample
'     for which resid is available and was not for the previous one

'     (s) eliminates the AR part from the forecast

smpl 1962 2012 if (resid<>na) and (resid(-1)=na)
_eq_popac.forecast(d,s) _z
genr popac_ec=d(popac)/pop1564(-1)-_z

'     Now we compute the residual for all periods but the first one
'     from the "official" residual and the memory of the previous computed one
'     applying the AR coefficient

smpl 1962 2012 if (resid_popac<>na) and (resid_popac(-1)<>na)
genr popac_ec=resid_popac+popac_ec(-1)*c_popac(6)

'      For the out-of-sample periods we apply the usual formula
 
'   There might be a simpler method but this one works
'    and it is easy to reproduce

'    ----------------------------------------------------------

'    estimating the GDP deflator

show err_pq
smpl 1962 2012
scalar p_cost=0.05
genr cost=wr*lf*(1+r_scf)/q  ' +p_cost*pip*k(-1))/q
coef(10) c_pq
vector(10) p_pq
genr pq_ec=0
smpl 1962 2012
equation _eq_pq1.ls(p) dlog(pq)=c_pq(1)*dlog(uwc)+c_pq(2)*dlog(ur)-c_pq(3)*(log(pq(-1)/uwc(-1))-c_pq(2)*log(ur(-1)))+c_pq(5)+pq_ec

p_pq(1)=0.6
p_pq(2)=0.2
p_pq(3)=0.3
equation _eq_pq.ls(p) dlog(pq)=p_pq(1)*dlog(uwc)+p_pq(2)*dlog(ur)-p_pq(3)*(log(pq(-1)/uwc(-1))-p_pq(2)*log(ur(-1)))+c_pq(5)+pq_ec
genr pq_ec=resid 

'    ----- estimating the wage rate -----------------------------------------------------

'      This time we apply cointegration
'      we would like to use this technique more often
'      but we did not find another working case

show err_wr 
coef(10) c_wr
vector(10) p_wr

'    we have to create an intermediary variable
 
smpl 1962 2012
genr wr_ec=0 
smpl 1962 2012
equation _eq_wr1.ls(p) dlog(wr)=c_wr(1)*dlog(pcoh)+c_wr(3)*(log(uwc(-1))-0.5*log(pcoh(-1))-0.5*log(pq(-1)))+c_wr(4)+wr_ec

p_wr(1)=0.60
p_wr(2)=-0.01
p_wr(3)=-0.35
p_wr(5)=0.7
equation _eq_wr.ls(p) dlog(wr)=p_wr(1)*dlog(pcoh)+p_wr(5)*dlog(lp)+p_wr(2)*log(unr)+p_wr(3)*(log(uwc(-1))-0.5*log(pcoh(-1))-0.5*log(pq(-1)))+c_wr(4)+wr_ec
genr wr_ec=resid 

'    ----------------------------------------------------------


'    estimating the import price

coef(10) c_pm
vector(10) p_pm
smpl 1962 2012
genr pm_ec=0
smpl @all
p_pm(1)=0.2
p_pm(2)=0.6
p_pm(3)=0.3
p_pm(4)=0.1
equation _eq_pm1.ls(p) dlog(pm)=c_pm(1)*dlog(pp)+c_pm(2)*dlog(ppx*er)+p_pm(3)*(log(pm(-1))-p_pm(4)*log(pp(-1))-(1-p_pm(4))*log(ppx(-1)*er(-1)))+c_pm(5)*(t-2012)*(t<=2012)+c_pm(6) +pm_ec

equation _eq_pm.ls(p) dlog(pm)=p_pm(1)*dlog(pp)+p_pm(2)*dlog(ppx*er)-p_pm(3)*(log(pm(-1))-p_pm(4)*log(pp(-1))-(1-p_pm(4))*log(ppx(-1)*er(-1)))+c_pm(5)*(t-2012)*(t<=2012)*(t<=2012)+c_pm(6) +pm_ec
 
genr pm_ec=resid 

'    ----------------------------------------------------------


'    estimating the export price


show err_px
coef(10) c_px
vector(10) p_px
smpl @all
genr px_ec=0
p_px(4)=0.6 
equation _eq_px1.ls(p) dlog(px)=c_px(1)*dlog(pp)+c_px(2)*dlog(ppx*er)+c_px(3)*(log(px(-1))-p_px(4)*log(pp(-1))-(1-p_px(4))*log(ppx(-1)*er(-1)))+c_px(5)*(t-2012)*(t<=2012)+c_px(6) +px_ec

p_px(1)=0.6 
p_px(2)=0.4
p_px(3)=0.30
p_px(4)=0.6 
equation _eq_px.ls(p) dlog(px)=p_px(1)*dlog(pp)+p_px(2)*dlog(ppx*er)-p_px(3)*(log(px(-1))-p_px(4)*log(pp(-1))-(1-p_px(4))*log(ppx(-1)*er(-1)))+c_px(5)*(t-2012)*(t<=2012)+p_px(6) +px_ec
genr px_ec=resid

'    ----------------------------------------------------------

'    estimating household consumption

show err_coh
coef(10) c_coh
vector(10) p_coh
smpl 1962 2012
genr coh_ec=0
smpl 1962 2012

equation _eq_coh1.ls(p) dlog(coh)=c_coh(1)*dlog(hrdi)+c_coh(3)*dlog(pcoh)+c_coh(5)+c_coh(6)*log(coh(-1)/hrdi(-1))+c_coh(7)*(t-2012)*(t<=2012)+coh_ec+p_coh(2)*dlog(unr)+c_coh(4)*irsr

p_coh(3)=0.6
p_coh(4)=-0.0
p_coh(5)=-0.2
p_coh(6)=-0.003
p_coh(7)=-0.003

equation _eq_coh.ls(p) dlog(coh)=c_coh(1)+c_coh(2)*(t-2012)*(t<=2012)+c_coh(3)*dlog(hrdi)+c_coh(4)*dlog(pcoh)+c_coh(5)*log(coh(-1)/hrdi(-1))+p_coh(6)*d(unr)+c_coh(7)*(irs-100*@pch(pcoh))+coh_ec
genr coh_ec=resid 


'    ----------------------------------------------------------

'    estimating imports

show err_m
coef(10) c_m
vector(10) p_m
smpl 1962 2012
genr m_ec=0
smpl 1962 2012
equation _eq_m1.ls(p)dlog(m)=c_m(1)*dlog(td)+c_m(2)*dlog(ur)+c_m(3)*dlog(compm)+c_m(4)+c_m(5)*(log(m(-1)/td(-1))-c_m(2)*log(ur(-1))-c_m(3)*log(compm(-1)))+c_m(6)*(t-2012)*(t<=2012)+m_ec

p_m(1)=0.8
p_m(2)=0.1
p_m(3)=0.0
p_m(5)=-0.3 
equation _eq_m.ls(p) dlog(m)=c_m(1)*dlog(td)+p_m(2)*dlog(ur)+c_m(3)*dlog(compm)+c_m(4)+c_m(5)*(log(m(-1)/td(-1))-p_m(2)*log(ur(-1))-c_m(3)*log(compm(-1))) +c_m(6)*(t-2012)*(t<=2012)+m_ec
genr m_ec=resid 




'    ----------------------------------------------------------

'    estimating exports

show err_x
coef(10) c_x
vector(10) p_x
smpl 1962 2012
genr x_ec=0
smpl 1962 2012
equation _eq_x1.ls(p) dlog(x)=c_x(1)*dlog(wd)+c_x(2)*log(x(-1)/wd(-1))+c_x(3)*log(ur)+c_x(4)*log(compx)+c_x(5)+c_x(6)*(t-2012)*(t<=2012)+x_ec

p_x(1)=1.0
p_x(2)=-0.3
p_x(3)=-0.3
p_x(4)=-0.3
equation _eq_x.ls(p) dlog(x)=c_x(1)*dlog(wd)+c_x(2)*log(x(-1)/wd(-1))+c_x(3)*log(ur)+c_x(4)*log(compx)+c_x(5)+c_x(6)*(t-2012)*(t<=2012)+x_ec
genr x_ec=resid 

'   ==============================================

'    creating the model

'   ==============================================


'     creating a blank model

delete(noerr) _mod_sen
model _mod_sen

'      scalars

scalar f
scalar r_vat0=s_r_vat0
scalar r_tar0=s_r_tar0
scalar r_tarx0=s_r_tarx0

smpl 1962 2012
'==============================
'     production block
'==============================

_mod_sen.append GDPM=FD+X-M
_mod_sen.append Q=GDPM-r_vat0*FD/(1+r_vat0)

_mod_sen.merge _eq_cap
_mod_sen.append UR=Q/CAP
_mod_sen.append log(lpt)=c_lpt(1)+c_lpt(2)*(t-2012)*(t<=2012)+log((1+txq)/(1+txn))*(t-2012)*(t>=2012) 
_mod_sen.append lfd=q/lpt
_mod_sen.merge _eq_lf
_mod_sen.append lw=lf*r_lw
_mod_sen.append LT=LF+lg 
_mod_sen.append lp=Q/LF 
_mod_sen.merge _eq_ip
_mod_sen.append k=k(-1)*(1-rdep)+ip
p_ic(1)=0.1 
_mod_sen.append ic/q(-1)=p_ic(1)*d(q)/q(-1) 
_mod_sen.merge _eq_popac
_mod_sen.append UN=POPAC-LT
_mod_sen.append UNR=UN/POPAC*100

'    price block

_mod_sen.append UWC=WR*(1+r_scf)/LP  
_mod_sen.merge _eq_pq
_mod_sen.append PP=(PQ+tc*PFDXT)/(1+tc)
_mod_sen.append FDV=GDPMv+Mv-Xv 
_mod_sen.append PFD=FDV/FD
_mod_sen.append PFDXT=PFD*(1+r_vat0)/(1+r_vat) 
_mod_sen.append pcoh=r_pcoh*PFD
_mod_sen.append pip=r_pip*PFD
_mod_sen.append PIG=r_pig*PFD 
_mod_sen.merge _eq_wr
_mod_sen.append cost=(wr*lf*(1+r_scf))/q
_mod_sen.merge _eq_px
_mod_sen.merge _eq_pm
scalar p_er=1
_mod_sen.append dlog(ER)=(p_er=1)*dlog(erx)+(p_er=2)*dlog(pcoh)
scalar p_irs=2
_mod_sen.append IRS=(p_irs=1)*IRSX+(p_IRS=2)*(IRSR+100*@pchy(pcoh))+(p_IRS=3)*(150*@pchy(pcoh)+50*(UR-urd)/urd+irst)
_mod_sen.append IRL=@movav(IRS,4)+IRL_ER
genr irl_er=(IRL-@movav(IRS,4))
scalar p_ir=0.5
_mod_sen.append IR=p_ir*IRS+(1-p_ir)*IRL+ir_eR
genr ir_er=IR-(p_ir*IRS+(1-p_ir)*IRL)
scalar p_irm=0.8
_mod_sen.append IRM=p_irm*IRM(-1)+(1-p_irm)*IR
_mod_sen.append relc=wr*(1+r_scf)/pip/(ir/100-@pchy(pcoh)+rdep)

'   households block

_mod_sen.append REM=REMX*ER
_mod_sen.append REVX=r_revx*PFD
_mod_sen.append SOCB=socbr*pcoh*popt
_mod_sen.append WageG=WR*lg
_mod_sen.append Wage=WageF+WageG
_mod_sen.append SCW=r_scw*Wage
_mod_sen.append HI=Wage-SCW+REVQ+REVX+SOCB+rem
_mod_sen.append ICT=r_ict*HI   '  *****rem : lagged???
_mod_sen.append HDI=HI-ICT
_mod_sen.append HRDI=HDI/pcoh
_mod_sen.append IH=R_IH*HRDI
_mod_sen.merge _eq_coh

'    firms block

_mod_sen.append Qv=PQ*Q
_mod_sen.append GDPMv=Qv+VAT
_mod_sen.append pgdpm=GDPMv/GDPM
_mod_sen.append WageF=WR*lw
_mod_sen.append SUBS=r_subs*Qv
_mod_sen.append MARG=PQ*Q*(1+r_subs-r_oit)-Wagef*(1+r_scf)
_mod_sen.append RMARG=MARG/Qv
_mod_sen.append IFP=(marg-revq-ifp)*r_ifp
_mod_sen.append NIF=NIF(-1)*IRM/IRM(-1)-IR/100*FCAPF+nif_er*qv
_mod_sen.append REVQ=R_REVQ*QV
_mod_sen.append PROF=MARG-REVQ-IFP-NIF
_mod_sen.append RPROF=PROF/(PFD*K(-1))
_mod_sen.append RPROB=MARG/(PFD*K(-1))
_mod_sen.append FCAPF=PROF-pip*I-PFD*IC
_mod_sen.append I=IP+IH+IG

'     external trade block

_mod_sen.append PMT=PM*(1+r_tar)/(1+r_tar0)
_mod_sen.append COMPM=PMT/PP 
_mod_sen.append FD=COH+IP+IH+IC+cog+IG+fdxr*Q
_mod_sen.append CI=tc*Q
_mod_sen.append TD=FD+CI
_mod_sen.merge _eq_m
_mod_sen.append COMPX=PX*(1+r_tarx)/(1+r_tarx0)/(PPX*ER)
_mod_sen.merge _eq_x
_mod_sen.append Mv=PM*M
_mod_sen.append Xv=PX*X
_mod_sen.append RCval=Xv/Mv
_mod_sen.append RCVOL=X/M
_mod_sen.append TTRAD=PX/PM
_mod_sen.append TRB=Xv-Mv
scalar p_nix=0.5
_mod_sen.append NIXD=NIXD(-1)*IRM/IRM(-1)-IR/100*p_nix*TRB+nixd_ec*(xv+mv)
_mod_sen.append NIXX=NIXX(-1)*IRMX/IRMX(-1)*(er/er(-1))-IRX/100*((1-p_nix)*TRB) +nixx_ec*(xv+mv)
_mod_sen.append NIX=NIXD+NIXX
_mod_sen.append FCAPX=TRB-NIX
'
'     State budget block
'
_mod_sen.append VAT=r_vat*PFD*FD/(1+r_vat)
_mod_sen.append SCF=r_scf*Wagef
_mod_sen.append OIT=r_oit*(Qv-oit)
_mod_sen.append TAR=r_tar*Mv
_mod_sen.append Scg=R_Scg*WAGEG
_mod_sen.append REVG=SCF+Scg+SCW+OIT+IFP+ICT+VAT+TAR+r_revg*Qv
_mod_sen.append IGV=IG*PIG
_mod_sen.append PCOG=PFD*R_PCOG
_mod_sen.append cogV=cog*Pcog
_mod_sen.append FDGV=cogV+IGV
_mod_sen.append NIG=NIG(-1)*IRM/IRM(-1)-IR/100*FCAPG+nig_er*qv
_mod_sen.append EXPG=FDGV+WAGEG+SUBS+SOCB+NIG+Scg+r_expg*Qv
_mod_sen.append FCAPG=REVG-EXPG
_mod_sen.append FCAPGP=100*FCAPG/gdpmv

'     We check the residuals

_mod_sen.append assign @all _c

smpl 2000 2012


_mod_sen.makegroup(a,n) _g_vendog @endog
_mod_sen.makegroup(a,n) _g_vexog @exog
_mod_sen.makegroup(a,n) _g_viden @endog
group _g_vbeha

for !i=1 to _g_vendog.@count
%1=_g_vendog.@seriesname(!i)
scalar  {%1}_is=@isobject(%1+"_ec")
if  {%1}_is=1 then
_g_vbeha.add {%1}
_g_viden.drop {%1}
endif
next


_mod_sen.append assign @all _c
_mod_sen.solve(d=f) 

for !i=1 to _g_vendog.@count
%1=_g_vendog.@seriesname(!i)
genr dc_{%1}={%1}-{%1}_c
genr pc_{%1}=100*dc_{%1}/({%1}+({%1}=0))
next
smpl 1960 2020
save model_sen


