'
'===========================================
'       This program performs simulations over the future
     
'       Behaviors can be changed
'       Assumptions are set0
'       Endogenous are initialized
'       A base simulation is produced
'       Assumptions are shocked 
'           and the consequences measured

'===========================================

'      We set the directory

cd "c:\users\jean louis brillet\documents\eviews\book_africa\senegal"

'    We define the output file as proj_1.rtf

output(r) proj_sen

%exclude="   " 

'      We copy the original mod_sen file into a forecast file called proj_1

'
close model_sen
close proj_sen
open model_sen
save proj_sen

'   Now we work on the future

'   We copy the page under a new name

pageselect model
pagecopy(page=forecast)

'     We extend the period to 2100

pagestruct(end=2100) * 

'     We define long-term growth rates 
'     Actually they will be applied to Growth ratess (the same to the first order)
'     as we shall see later


scalar txq=0.05
scalar txn=0.01
scalar txp=0.05

	'   Constant Values : Growth rates=0

smpl @all 

smpl 2013 2100
for %1 COH_EC ERX FDXR  K_EC CI_EC IR_ER IRL_ER IRMX IRSR IRST IRSX IRX LF_EC  M_EC NIF_ER NIG_ER PK PM_EC POPAC_EC PQ_EC PX_EC R_EXPG R_ICT R_IFP R_OIT R_PCOH R_PCOG R_PI R_PIG R_REVG R_REVQ R_SCF R_SCG R_SCW R_SUBS R_TAR R_TARX R_VAT RDEP TC URD  WR_EC X_EC IRM_ER NIXD_EC NIXX_EC R_IH R_LW R_PIP IC_EC IP_EC fcapf_er prof_er
genr {%1}={%1}(-1)
next

	'  Variables at constant prices : Growth rates=txq

for %1  COG   IG   WD R_REVX  
genr {%1}={%1}(-1)*(1+txq)
next

	'  Populations : Growth rates=txn

for %1 LG POP1564 POP
genr {%1}={%1}(-1)*(1+txn)
next

	'  Prices : Growth rates=txp

for %1  PPX 
genr {%1}={%1}(-1)*(1+txp)
next

	'  Values : Growth rates=txp+txq

for %1  REMX 
genr {%1}={%1}(-1)*(1+txp)*(1+txq)
next

'            Purchasing power per head : Growth rates=txp-txn

for %1   SOCBR
genr {%1}={%1}(-1)*(1+txq)/(1+txn)
next

'            The time trend

genr t=t(-1)+1

'             Now we give Vues to the endogenous
'             There are two main reasons

'             1 - This gives an alternate starting point for the solution algorithms
'              Sometimes this starting point is more efficient
'              One can just check

'             2 - This allows to make a residual check on the future
'              which is useful to check that :
'              using the exogenous assumptions 
'              applying the formula provides a steady state path
'              with the same growth rate as the variable it computes

'              When the condition is met for all equations
'              a steady state path exists
'              and will be reached provided the process is converging

'              A difference can come from :
'              - wrong dimensions in the assumptions
'              - non homogenous formulas
'              - wrong initialization of endogenous (not a real problem)

smpl 2013 2100
 
'        Constant Vues : Growth rates=0

for %1   COMPM COMPX ER  FCAPGP IR IRL IRM IRS RCVAL RCVOL RES_WR  RMARG RPROB RPROF TTRAD UNR  UR
genr {%1}={%1}(-1)
next

'       Variables at constant prices : Growth rates=txq

for %1  CAP COH  FD HRDI I IP IH CI K  M  Q  X GDPM IC  TD
genr {%1}={%1}(-1)*(1+txq)
next

'       Populations : Growth rates=txn

for %1 LFD  LF LW LS LT   POPAC UN  popt
genr {%1}={%1}(-1)*(1+txn)
next

'      Deflators : Growth rates = txp

for %1    COST PCOG PCOH PFD PFDXT PPI PIG PM PMT  PP PQ PX UWC PGDPM PIP
genr {%1}={%1}(-1)*(1+txp) 
next

'       Variables at current prices : Growth rates = txp+txq

for %1 COGV  EXPG FCAPF FCAPG FCAPX FDGV HDI HI ICT IFP IGV MARG MV NIF NIG NIX NIXL NIXX OIT PROF GDPMV QV  REVG REVQ REVX  SCF SCG SCW SOCB SUBS TAR TRB  VAT XV  NIXD WAGE WAGEF WAGEG REM FDV
genr {%1}={%1}(-1)*(1+txp)*(1+txq)
next

'       Variables at current prices  per head : Growth rates=txp+txq-txn

for %1 WR  
genr {%1}={%1}(-1)*(1+txp)*(1+txq)/(1+txn)
next

'      Variables at constant prices  per head : Growth rates=txp+txq-txn

for %1 LP LPT RELC
genr {%1}={%1}(-1)*(1+txq)/(1+txn)
next 

'    Shock on prices

genr pq_ec=pq_ec+0.02
genr wr_ec=wr_ec+0.02 


'==========================================================
'     Solving the model on the future (basic simulation)

'==========================================================

'      Now we solve the model on the future
'      until 2100
'      using the basic assumptions

'       The scenario is "scenario 1"
'       The suffix is "_b"
'       The convergence criterion is 10-6 
'                   (relative difference from an iteration to the next)
'        The maximum number of iterations is 1001
'                    giving a special number can help to associate a failure message
'                    to a specific solve statement'               
'        The exclude statement states that all endogenous will be computed
'                    it cancels any previous exclusions
'                    which may remain from previous simulations of "Scenario 1"

'          First we shall test that each equation result gives the normal growth rate
'          We use a residual check on the future
'         and we compare the growth rate to the theoretical one

smpl 2013 2100 
_mod_sen.solveopt(n=t,m=1000,c=1e-6,o=b,d=f )
_mod_sen.scenario "scenario 1"
_mod_sen.append assign @all _d
_mod_sen.exclude {%exclude}
smpl 2013 2100
solve(n=t,m=1001,c=1e-8,o=b,d=f ) _mod_sen 

'         Now we compute the growth rates 
 

for !i=1 to _g_vendog.@count
%st1=_g_vendog.@seriesname(!i)
smpl 2013 2100
series {%st1}_td=100*({%st1}_d-{%st1}_d(-1))/({%st1}_d(-1)+({%st1}_d(-1)=0))  
series {%st1}_tc0=100*({%st1}-{%st1}(-1))/({%st1}(-1)+({%st1}(-1)=0))  
series {%st1}_DTd={%st1}_td-{%st1}_tc0
next 

'       Now we make the actual simulation

smpl 2013 2100 
_mod_sen.solveopt(n=t,m=1000,c=1e-6,o=b,d=d )
_mod_sen.scenario "scenario 1"
_mod_sen.append assign @all _b
_mod_sen.exclude {%exclude}
smpl 2013 2100
solve(n=t,m=1001,c=1e-8,o=b,d=d ) _mod_sen 

'         Now we compute the growth rates
'         or rather here the Growth ratess

'         We compute the ratio of the present to the previous Vue
'         for each endogenous
'         If it is positive we take the logarithm to get the Growth rates
'         otherwise we give the Vue "na"
'         This gives the same result as a direct computation
'          but avoids the error messages
'             Now we do the same for the initialization Vues
'             and compute the difference on the growth rates

for !i=1 to _g_vendog.@count
%st1=_g_vendog.@seriesname(!i)
smpl 2013 2100
series {%st1}_tc=100*({%st1}_b-{%st1}_b(-1))/({%st1}_b(-1)+({%st1}_b(-1)=0))  
series {%st1}_tc0=100*({%st1}-{%st1}(-1))/({%st1}(-1)+({%st1}(-1)=0))  
series {%st1}_DTC=100*({%st1}_tc-{%st1}_tc0)
next 



group g_table GDPM_tc FD_tc ip_tc i_tc coh_tc M_tc X_tc  100*RCVOL_b CAP_tc UR_b*100 PGDPM_tc X_tc PM_tc PCOH_tc pp_TC WR_tc COMPX_tc COMPM_tc Lf_tc LT_tc  UNR_b RMARG_b*100 RPROB_b*100 
smpl 2013 2025
 
if @isobject("__proj") then
delete __proj
endif

show(t) g_table
freeze(__proj) g_table
__proj.deleterow(2)
__proj.insertrow(2)
__proj.insertrow(13)
__proj.insertrow(22)
__proj.insertrow(26)
__proj.insertrow(29)
__proj.setjust(A1:A28)left
__proj.setjust(A1:N1) center
__proj.setwidth(A) 26
__proj.setwidth(B:N) 6.5
__proj.setformat(B2:N28) f.2
__proj.setlines(A1:N28) +o
__proj.setlines(A1:N1) +b
__proj.setlines(A12:N12) +b
__proj.setlines(A21:N21) +b
__proj.setlines(A25:N25) +b
__proj.setlines(A28:N28) +b 
__proj.setlines(A1:A28) +r
__proj.setfont(A2) +b
__proj.setfont(A13) +b
__proj.setfont(A22) +b
__proj.setfont(A26) +b 

__proj(1,1)=""

__proj(2,1)="Real equlibrium"
__proj(3,1)="GDP"
__proj(4,1)="Final demand"
__proj(5,1)="Productive Investment"
__proj(6,1)="Total Investment"
__proj(7,1)="Household Consumption"
__proj(8,1)="Imports"
__proj(9,1)="Exports"
__proj(10,1)="Export-import ratio"
__proj(11,1)="Productive capacity"
__proj(12,1)="Rate of use (*)"
__proj(13,1)="Deflators"
__proj(14,1)="GDP  "
__proj(15,1)="Exports  "
__proj(16,1)="Imports  "
__proj(17,1)="Consumer price index"
__proj(18,1)="Production price"
__proj(19,1)="Wage rate"
__proj(20,1)="Export competitiveness"
__proj(21,1)="Import competitiveness"
__proj(22,1)="Employment"
__proj(23,1)="Firms employment"
__proj(24,1)="Total employment"
__proj(25,1)="Unemployment rate (*)"
__proj(26,1)="Others"
__proj(27,1)="Margins rate (*)"
__proj(28,1)="Profits rate (*)" 
__proj.setindent(A) 4

close g_table
show __proj 

'==========================================================
'     Solving the model on the future (shocked assumptions)
'==========================================================

'     Now we shall produce a set shocks (in the present case 7)

smpl 2000 2100

'    The group called shocks_v will contain the list of 7 shocked variables

group shocks_v erx r_vat r_tar r_tarx wd m_ec ig

'    The group called shocks_l will contain 7 letters associated to each shock
'     but the letters must be known as series 
'     as groups can contain only series

'     We create artificial series 
'      but only for the non-existing ones of course (not t or x or m.......)

delete f
for %1 ex vt tl tx wd im gd
if @isobject(%1)=0 then
genr {%1}=na
endif
next

'      We create the group

group shocks_l  ex vt tl tx wd im gd

'    Now we compute the additional change for each assumption, 
'    using the name of the variable
'    The shock will only start in 2006
'    to check that the difference comes only from the shock

'      1 - Shock g : +1 GDP point on Government demand

genr ig_gd=ig+.01*gdpm_b*(t>=2014)

'      2 - Shock r : 1% devaluation of the Euro

genr erx_ex=erx*(1+.01*(t>=2014))

'      3 - Shock t : -1 point on the VAT rate

genr r_vat_vt=r_vat-.01*(t>=2014)

'      4 - Shock f : -1 point on the local tariffs rate

genr r_tar_tl=r_tar-.01*(t>=2014)

'      5 - Shock y : -1 point on the foreign tariffs rate

genr r_tarx_tx=r_tarx-.01*(t>=2014)

'      6 - Shock w : +1% on World demand addressed to France

genr wd_wd=wd*(1+.01*(t>=2014))

'      7 - Shock n : +1% on ex-ante imports

genr m_ec_im=m_ec+.01*(t>=2014) 

'     The loop on the shocks

for !j=1 to  shocks_v.@count

smpl 2013 2100

'   We get the name of the shocked variable and the associated letter

%2=shocks_v.@seriesname(!j)
%3=shocks_l.@seriesname(!j)

'    We set the solution suffix using the letter 
'    We control no endogenous is excluded from the simulation
'    We override the variable associated to the current shock
'    We solve the model

smpl 2013 2100

'    We solve the model

_mod_sen.scenario "scenario 1"
_mod_sen.append assign @all _{%3}
_mod_sen.exclude   {%exclude}
_mod_sen.override {%2}
solve(n=t,m=1000+!j,c=1e-8,o=b,d=d) _mod_sen

'   We compute the difference to the base simulation, in absolute and relative terms

for !i=1 to _g_vendog.@count
%st1=_g_vendog.@seriesname(!i)
series d{%3}_{%st1}={%st1}_{%3}-{%st1}_b
series p{%3}_{%st1}=100* d{%3}_{%st1}/({%st1}_b+ ({%st1}_b=0))
series dv_{%st1}=d{%3}_{%st1}
series pv_{%st1}=p{%3}_{%st1}
next

'   We create groups for variations for a specific list of important variables

group g_v{%3} P{%3}_PFD P{%3}_PM P{%3}_PX P{%3}_PQ P{%3}_WR P{%3}_FD P{%3}_gdpm P{%3}_X P{%3}_M P{%3}_I P{%3}_COH P{%3}_UR P{%3}_CAP  P{%3}_LF P{%3}_K P{%3}_UNR  D{%3}_FCAPGP P{%3}_RCVAL P{%3}_RCVOL P{%3}_TTRAD 

'   Or very important ones

group g_w{%3} P{%3}_FD P{%3}_gdpm P{%3}_X P{%3}_M   P{%3}_PQ  

'    We create a group for variations for all variables

group g_v2 pV_* dV_* 

'      We store all shocks in Excel files (2025 and 2100)
'      using the letter associated to the shock

smpl 2013 2025
write(t=xls) v2_{%3}.xls g_v2 
smpl 2013 2100
write(t=xls) w2_{%3}.xls g_v2 

output(r) graph_1

alpha title_gd="Government demand"
alpha title_ex="the exchange rate"
alpha title_vt="the Vue added tax" 
alpha title_tl="shock on local tariffs"
alpha title_tx="shock on foreign tariffs"
alpha title_wd="shock on foreign quotas"
alpha title_im="shock on local quotas"  

alpha units_gd="+1 point of GDP"
alpha units_ex="+1 point of the rate"
alpha units_vt="-1 point of the rate"
alpha units_tl="-1 point of the rate"
alpha units_tx="+1% of ex ante world demand"
alpha units_wd="-1 point of the rate"
alpha units_im="+1% of ex ante imports "

%title=@elem(title_{%3},"2020")
%units=@elem(units_{%3},"2020")

smpl 2013 2025

'    Supply - demand graph
 
graph _gr_{%3}1.line P{%3}_fd P{%3}_gdpm P{%3}_x P{%3}_m P{%3}_pq   
_gr_{%3}1.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(Final demand)
_gr_{%3}1.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(GDP)
_gr_{%3}1.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(Exports)
_gr_{%3}1.setelem(4) symbol(4) lcolor(orange) lwidth(0.25) lpat(4) legend(Imports)
_gr_{%3}1.setelem(5) symbol(10) lcolor(purple) lwidth(0.25) lpat(5) legend(GDP deflator) 
_gr_{%3}1.legend position(botleft)
_gr_{%3}1.axis(left) grid
_gr_{%3}1.axis(bottom) grid 
_gr_{%3}1.addtext(t,font=12,x) {%title} : The supply - demand equilibrium  
_gr_{%3}1.addtext(l,font=11) in percentage 
_gr_{%3}1.addtext(r,font=10) shock : {%units}

print(l) _gr_{%3}1

close _gr_{%3}1 

'    Production

graph _gr_{%3}2.line P{%3}_q p{%3}_cap p{%3}_k p{%3}_lf p{%3}_ur
_gr_{%3}2.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(Vue added)
_gr_{%3}2.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(Capacity)
_gr_{%3}2.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(Capital)
_gr_{%3}2.setelem(4) symbol(4) lcolor(orange) lwidth(0.25) lpat(4) legend(Employment)
_gr_{%3}2.setelem(5) symbol(10) lcolor(purple) lwidth(0.25) lpat(5) legend(Rate of use) 
_gr_{%3}2.legend position(botleft)
_gr_{%3}2.axis(left) grid
_gr_{%3}2.axis(bottom) grid 
_gr_{%3}2.addtext(t,font=12,x)  {%title} : The production elements 
_gr_{%3}2.addtext(l,font=11) in percentage
_gr_{%3}2.addtext(r,font=10) shock : {%units} 

print(l) _gr_{%3}2

close _gr_{%3}2


'    Ratios

graph _gr_{%3}3.line  p{%3}_relc p{%3}_k-p{%3}_lf   p{%3}_ur d{%3}_unr
_gr_{%3}3.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(Relative cost)
_gr_{%3}3.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(Capital-Labour ratio)
_gr_{%3}3.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(Rate of use)
_gr_{%3}3.setelem(4) symbol(4) lcolor(orange) lwidth(0.25) lpat(4) legend(Unemployment rate in points) 
_gr_{%3}3.legend position(botleft)
_gr_{%3}3.axis(left) grid
_gr_{%3}3.axis(bottom) grid 
_gr_{%3}3.addtext(t,font=12,x)  {%title} : The ratios 
_gr_{%3}3.addtext(l,font=11) in percentage
_gr_{%3}3.addtext(r,font=10) shock : {%units}  

print(l) _gr_{%3}3

close _gr_{%3}3

'    External trade 1

graph _gr_{%3}4.line p{%3}_xV p{%3}_mV p{%3}_rcVAL
_gr_{%3}4.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(Exports)
_gr_{%3}4.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(Imports)
_gr_{%3}4.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(Exports-Imports ratio) 
_gr_{%3}4.legend position(botleft)
_gr_{%3}4.axis(left) grid
_gr_{%3}4.axis(bottom) grid 
_gr_{%3}4.addtext(t,font=12,x)  {%title} : External trade at current prices  
_gr_{%3}4.addtext(l,font=11) in percentage
_gr_{%3}4.addtext(r,font=10) shock : {%units}  

' print(l) _gr_{%3}4

close _gr_{%3}4


'    External trade 2

graph _gr_{%3}5.line p{%3}_rcvol p{%3}_ttrad p{%3}_rcVAL
_gr_{%3}5.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(At constant prices)
_gr_{%3}5.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(Terms of trade)
_gr_{%3}5.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(At constant prices) 
_gr_{%3}5.legend position(botleft)
_gr_{%3}5.axis(left) grid
_gr_{%3}5.axis(bottom) grid 
_gr_{%3}5.addtext(t,font=12,x)  {%title} : The exports - import ratios 
_gr_{%3}5.addtext(l,font=11) in percentage
_gr_{%3}5.addtext(r,font=10) shock : {%units}  

print(l) _gr_{%3}5

close _gr_{%3}5

'    Prices

graph _gr_{%3}6.line p{%3}_wr p{%3}_pfd p{%3}_pq p{%3}_px p{%3}_pm
_gr_{%3}6.setelem(1) symbol(1) lcolor(blue) lwidth(0.25) lpat(1) legend(Wage rate)
_gr_{%3}6.setelem(2) symbol(2) lcolor(red) lwidth(0.25) lpat(2) legend(Consumption)
_gr_{%3}6.setelem(3) symbol(8)lcolor(green) lwidth(0.25) lpat(3) legend(Vue added)
_gr_{%3}6.setelem(4) symbol(4) lcolor(orange) lwidth(0.25) lpat(4) legend(Exports)
_gr_{%3}6.setelem(5) symbol(10) lcolor(purple) lwidth(0.25) lpat(5) legend(Imports) 
_gr_{%3}6.legend position(botleft)
_gr_{%3}6.axis(left) grid
_gr_{%3}6.axis(bottom) grid 
_gr_{%3}6.addtext(t,font=12,x)  {%title} : The prices   
_gr_{%3}6.addtext(l,font=11) in percentage 
_gr_{%3}6.addtext(r,font=10) shock : {%units} 


graph _gr{%3}tot.merge _gr_{%3}1 _gr_{%3}2 _gr_{%3}3 _gr_{%3}4 _gr_{%3}5 _gr_{%3}6  
_gr{%3}tot.align(3,2,2)

' print(l) _gr_{%3}6

close _gr_{%3}6

group g_t{%3} p{%3}_GDPM p{%3}_FD p{%3}_ip p{%3}_i p{%3}_coh p{%3}_M p{%3}_X p{%3}_RCVOL p{%3}_CAP p{%3}_UR  p{%3}_PGDPM p{%3}_PX p{%3}_PM p{%3}_PCOH p{%3}_WR p{%3}_COMPX p{%3}_COMPM p{%3}_Lf p{%3}_LT d{%3}_UNR  100*d{%3}_RMARG 100*d{%3}_RPROB
smpl 2013 2025
 
%tab="_TAB"+%3
if @isobject(%tab) then
delete %tab
endif

smpl 2014 2026
'   show(t) g_t{%3}
freeze({%tab}) g_t{%3}
{%tab}.deleterow(2)
{%tab}.insertrow(2)
{%tab}.insertrow(13)
{%tab}.insertrow(21)
{%tab}.insertrow(25)
{%tab}.insertrow(28)
{%tab}.setjust(A1:A27)left
{%tab}.setjust(A1:N1) center
{%tab}.setwidth(A) 25
{%tab}.setwidth(B:N) 6.5
{%tab}.setformat(B2:N27) f.2
{%tab}.setlines(A1:N27) +o
{%tab}.setlines(A1:N1) +b
{%tab}.setlines(A12:N12) +b
{%tab}.setlines(A20:N20) +b
{%tab}.setlines(A24:N24) +b
{%tab}.setlines(A27:N27) +b 
{%tab}.setlines(A1:A27) +r
{%tab}.setfont(A2) +b
{%tab}.setfont(A13) +b
{%tab}.setfont(A21) +b
{%tab}.setfont(A25) +b 

{%tab}(1,1)=""

{%tab}(2,1)="Real equlibrium"
{%tab}(3,1)="GDP"
{%tab}(4,1)="Final demand"
{%tab}(5,1)="Productive Investment"
{%tab}(6,1)="Total Investment"
{%tab}(7,1)="Household Consumption"
{%tab}(8,1)="Imports"
{%tab}(9,1)="Exports"
{%tab}(10,1)="Export-import ratio"
{%tab}(11,1)="Productive capacity"
{%tab}(12,1)="Rate of use (*)"
{%tab}(13,1)="Deflators"
{%tab}(14,1)="GDP  "
{%tab}(15,1)="Exports  "
{%tab}(16,1)="Imports  "
{%tab}(17,1)="Consumer price index"
{%tab}(18,1)="Wage rate"
{%tab}(19,1)="Export competitiveness"
{%tab}(20,1)="Import competitiveness"
{%tab}(21,1)="Employment"
{%tab}(22,1)="Firms employment"
{%tab}(23,1)="Total employment"
{%tab}(24,1)="Unemployment rate (*)"
{%tab}(25,1)="Others"
{%tab}(26,1)="Margins rate (*)"
{%tab}(27,1)="Profits rate (*)" 
{%tab}.setindent(A) 4

close g_t{%3}
next

'       We save the workfile

save proj_sen.wf1


